@@ -31,7 +31,7 @@ _e_comp_canvas_cb_first_frame(void *data EINA_UNUSED, Evas *e, void *event_info
      {
       case 'A': abort();
       case 'E':
-      case 'D': exit(-1);
+      case 'D': exit(101);
       case 'T': fprintf(stderr, "Startup time: '%f' - '%f' = '%f'\n", now, e_first_frame_start_time, now - e_first_frame_start_time);
          break;
      }
@@ -42,6 +42,7 @@ _e_comp_canvas_cb_first_frame(void *data EINA_UNUSED, Evas *e, void *event_info
 static void
 _e_comp_canvas_render_post(void *data EINA_UNUSED, Evas *e EINA_UNUSED, void *event_info EINA_UNUSED)
 {
+   E_Comp_Config *conf = e_comp_config_get();
    E_Client *ec;
    //Evas_Event_Render_Post *ev = event_info;
    //Eina_List *l;
@@ -65,6 +66,11 @@ _e_comp_canvas_render_post(void *data EINA_UNUSED, Evas *e EINA_UNUSED, void *ev
         UNREFD(ec, 111);
         e_object_unref(E_OBJECT(ec));
      }
+   if (conf->grab && e_comp->grabbed)
+     {
+        if (e_comp->grab_cb) e_comp->grab_cb();
+        e_comp->grabbed = 0;
+     }
 }
 
 ///////////////////////////////////
@@ -74,7 +80,7 @@ _e_comp_canvas_cb_mouse_in(void *d EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object
 {
    E_Client *ec;
 
-   e_screensaver_notidle();
+   e_comp_canvas_notidle();
    if (e_client_action_get() || e_grabinput_mouse_win_get()) return;
    ec = e_client_focused_get();
    if (ec && (!ec->border_menu)) e_focus_event_mouse_out(ec);
@@ -83,7 +89,7 @@ _e_comp_canvas_cb_mouse_in(void *d EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object
 static void
 _e_comp_canvas_cb_mouse_down(void *d EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
-   e_screensaver_notidle();
+   e_comp_canvas_notidle();
    if (e_client_action_get() || e_grabinput_mouse_win_get()) return;
    e_bindings_mouse_down_evas_event_handle(E_BINDING_CONTEXT_COMPOSITOR, E_OBJECT(e_comp), event_info);
 }
@@ -91,7 +97,7 @@ _e_comp_canvas_cb_mouse_down(void *d EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Obje
 static void
 _e_comp_canvas_cb_mouse_up(void *d EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
-   e_screensaver_notidle();
+   e_comp_canvas_notidle();
    if (e_client_action_get() || e_grabinput_mouse_win_get()) return;
    e_bindings_mouse_up_evas_event_handle(E_BINDING_CONTEXT_COMPOSITOR, E_OBJECT(e_comp), event_info);
 }
@@ -99,7 +105,7 @@ _e_comp_canvas_cb_mouse_up(void *d EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object
 static void
 _e_comp_canvas_cb_mouse_wheel(void *d EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
-   e_screensaver_notidle();
+   e_comp_canvas_notidle();
    if (e_client_action_get() || e_grabinput_mouse_win_get()) return;
    e_bindings_wheel_evas_event_handle(E_BINDING_CONTEXT_COMPOSITOR, E_OBJECT(e_comp), event_info);
 }
@@ -107,7 +113,7 @@ _e_comp_canvas_cb_mouse_wheel(void *d EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Obj
 static Eina_Bool
 _key_down(int ctx, Ecore_Event_Key *ev)
 {
-   e_screensaver_notidle();
+   e_comp_canvas_notidle();
    if (e_desklock_state_get() && (ctx == E_BINDING_CONTEXT_MANAGER))
      {
         E_Desklock_Interface *iface = e_desklock_interface_current_get();
@@ -157,7 +163,7 @@ _e_comp_cb_key_down(void *data EINA_UNUSED, int ev_type EINA_UNUSED, Ecore_Event
 static Eina_Bool
 _key_up(int ctx, Ecore_Event_Key *ev)
 {
-   e_screensaver_notidle();
+   e_comp_canvas_notidle();
    if (e_desklock_state_get() && (ctx == E_BINDING_CONTEXT_MANAGER))
      {
         E_Desklock_Interface *iface = e_desklock_interface_current_get();
@@ -354,9 +360,16 @@ _e_comp_canvas_prerender(void *data EINA_UNUSED, Evas *e EINA_UNUSED, void *even
 {
    E_Comp_Cb cb;
    Eina_List *l;
+   E_Comp_Config *conf = e_comp_config_get();
 
    e_comp->rendering = EINA_TRUE;
 
+   if (conf->grab && (!e_comp->grabbed))
+     {
+        if (e_comp->grab_cb) e_comp->grab_cb();
+        e_comp->grabbed = 1;
+     }
+
    EINA_LIST_FOREACH(e_comp->pre_render_cbs, l, cb)
      cb();
 }
@@ -404,7 +417,7 @@ e_comp_canvas_init(int w, int h)
    //   ecore_evas_manual_render_set(e_comp->ee, conf->lock_fps);
    ecore_evas_show(e_comp->ee);
 
-   evas_event_callback_add(e_comp->evas, EVAS_CALLBACK_RENDER_POST, _e_comp_canvas_render_post, NULL);
+   evas_event_callback_add(e_comp->evas, EVAS_CALLBACK_RENDER_FLUSH_POST, _e_comp_canvas_render_post, NULL);
 
    e_comp->ee_win = ecore_evas_window_get(e_comp->ee);
 
@@ -437,6 +450,10 @@ e_comp_canvas_init(int w, int h)
    if ((!after_restart) || (!e_comp_x))
      ecore_evas_pointer_warp(e_comp->ee, e_comp->w / 2, e_comp->h / 2);
 
+#ifdef HAVE_WAYLAND
+   if (e_comp->comp_type == E_PIXMAP_TYPE_WL)
+     e_comp_wl_notidle();
+#endif
    return EINA_TRUE;
 }
 
@@ -874,6 +891,14 @@ e_comp_canvas_feed_mouse_up(unsigned int activate_time)
      }
 }
 
+E_API void
+e_comp_canvas_notidle(void)
+{
+#ifdef HAVE_WAYLAND
+   if (e_comp->comp_type == E_PIXMAP_TYPE_WL) e_comp_wl_notidle();
+#endif
+}
+
 E_API Evas_Object *
 e_comp_canvas_event_grabber_add(void)
 {
