@@ -285,9 +285,9 @@ _e_comp_wl_data_offer_cb_source_destroy(struct wl_listener *listener, void *data
    E_Comp_Wl_Data_Offer *offer;
 
    DBG("Data Offer Source Destroy");
+   if (!listener) return;
    offer = container_of(listener, E_Comp_Wl_Data_Offer,
                         source_destroy_listener);
-   if (!offer) return;
 
    offer->source = NULL;
 }
@@ -488,10 +488,11 @@ _e_comp_wl_data_device_selection_set(void *data EINA_UNUSED, E_Comp_Wl_Data_Sour
    sel_source = (E_Comp_Wl_Data_Source *)e_comp_wl->selection.data_source;
    if (sel_source && (e_comp_wl->selection.serial - serial < UINT32_MAX / 2))
      {
-        if (!serial)
+        if ((source) && (!serial))
           {
              /* drm canvas will always have serial 0 */
              pid_t pid;
+
              wl_client_get_credentials(wl_resource_get_client(source->resource), &pid, NULL, NULL);
              if (pid != getpid()) return;
           }
@@ -509,7 +510,8 @@ _e_comp_wl_data_device_selection_set(void *data EINA_UNUSED, E_Comp_Wl_Data_Sour
 
    e_comp_wl->selection.data_source = sel_source = source;
    e_comp_wl->clipboard.xwl_owner = 0;
-   source->serial = e_comp_wl->selection.serial = serial;
+   e_comp_wl->selection.serial = serial;
+   if (source) source->serial = serial;
 
    if (e_comp_wl->kbd.enabled)
      focus = e_comp_wl->kbd.focus;
@@ -999,7 +1001,7 @@ e_comp_wl_data_device_send_enter(E_Client *ec)
         d2 = d3 = d4 = 0;
         source = e_comp_wl->drag_source;
 
-        if (eina_array_count(source->mime_types) > 3)
+        if ((source->mime_types) && (eina_array_count(source->mime_types) > 3))
           {
              const char *type, *types[eina_array_count(source->mime_types)];
              int i = 0;
