@@ -75,7 +75,7 @@ _output_screen_get(Ecore_X_Window root, Ecore_X_Randr_Output o)
 static Ecore_X_Randr_Edid_Display_Interface_Type
 _output_conn_type_get(Ecore_X_Window root, Ecore_X_Randr_Output o)
 {
-   // get what kind of connector (hdmi, dvi, displayport etc.) - vga is 
+   // get what kind of connector (hdmi, dvi, displayport etc.) - vga is
    Ecore_X_Randr_Edid_Display_Interface_Type type;
    unsigned long len = 0;
    unsigned char *edid = ecore_x_randr_output_edid_get(root, o, &len);
@@ -433,6 +433,20 @@ _mode_screen_find(Ecore_X_Window root, E_Randr2_Screen *s, Ecore_X_Randr_Output
    return mode;
 }
 
+static Eina_Bool
+_cb_no_outputs_timer(void *data EINA_UNUSED)
+{
+   e_util_dialog_show(_("Screen setup Error"),
+                      _("You seem to have no screens configured to<br>"
+                        "be on given the outputs you have. This should<br>"
+                        "be fixed by going to:<br>"
+                        "<br>"
+                        "<b>Settings -> Screen -> Screen Setup</><br>"
+                        "<br>"
+                        "And configure at least one screen to be on."));
+   return EINA_FALSE;
+}
+
 E_API void
 e_comp_x_randr_init(void)
 {
@@ -476,6 +490,8 @@ e_comp_x_randr_config_apply(void)
    int crtcs_num = 0, outputs_num = 0, i, numout;
    Ecore_X_Randr_Crtc_Info *info;
    int top_priority = 0;
+   int px, py;
+   Eina_Bool fix_pointer = EINA_TRUE;
 
    ecore_x_grab();
    // set virtual resolution
@@ -495,6 +511,8 @@ e_comp_x_randr_config_apply(void)
    if (nh < minh) nh = minh;
    ww = nw; if (nw < pw) ww = pw;
    hh = nh; if (nh < ph) hh = ph;
+
+   ecore_x_pointer_xy_get(root, &px, &py);
    ecore_x_randr_screen_current_size_set(root, ww, hh, -1, -1);
      {
         int dww = 0, dhh = 0, dww2 = 0, dhh2 = 0;
@@ -560,64 +578,90 @@ e_comp_x_randr_config_apply(void)
           }
         if (numout)
           {
-        // set up a crtc to drive each output (or not)
-        for (i = 0; i < crtcs_num; i++)
-          {
-             // XXX: find clones and set them as outputs in an array
-             if (outconf[i])
-               {
-                  Ecore_X_Randr_Orientation orient =
-                    ECORE_X_RANDR_ORIENTATION_ROT_0;
-                  Ecore_X_Randr_Mode mode;
+             Ecore_X_Rectangle *scrs = alloca(crtcs_num * sizeof(Ecore_X_Rectangle));
+             int scrs_num;
 
-                  mode = _mode_screen_find(root, screenconf[i], outconf[i]);
-                  if (screenconf[i]->config.rotation == 0)
-                    orient = ECORE_X_RANDR_ORIENTATION_ROT_0;
-                  else if (screenconf[i]->config.rotation == 90)
-                    orient = ECORE_X_RANDR_ORIENTATION_ROT_90;
-                  else if (screenconf[i]->config.rotation == 180)
-                    orient = ECORE_X_RANDR_ORIENTATION_ROT_180;
-                  else if (screenconf[i]->config.rotation == 270)
-                    orient = ECORE_X_RANDR_ORIENTATION_ROT_270;
-                  printf("RRR: crtc on: %i = '%s'     @ %i %i    - %ix%i orient %i mode %x out %x\n",
-                         i, screenconf[i]->info.name,
-                         screenconf[i]->config.geom.x,
-                         screenconf[i]->config.geom.y,
-                         screenconf[i]->config.geom.w,
-                         screenconf[i]->config.geom.h,
-                         orient, mode, outconf[i]);
-                  if (!ecore_x_randr_crtc_settings_set
-                      (root, crtcs[i], &(outconf[i]), 1,
-                       screenconf[i]->config.geom.x,
-                       screenconf[i]->config.geom.y,
-                       mode, orient))
-                    printf("RRR:   failed to set crtc!!!!!!\n");
-                  ecore_x_randr_crtc_panning_area_set
-                    (root, crtcs[i],
-                     screenconf[i]->config.geom.x,
-                     screenconf[i]->config.geom.y,
-                     screenconf[i]->config.geom.w,
-                     screenconf[i]->config.geom.h);
-                  if (screenconf[i]->config.priority == top_priority)
+             scrs_num = 0;
+             // set up a crtc to drive each output (or not)
+             for (i = 0; i < crtcs_num; i++)
+               {
+                  // XXX: find clones and set them as outputs in an array
+                  if (outconf[i])
                     {
-                       ecore_x_randr_primary_output_set(root, outconf[i]);
-                       top_priority = -1;
+                       Ecore_X_Randr_Orientation orient =
+                         ECORE_X_RANDR_ORIENTATION_ROT_0;
+                       Ecore_X_Randr_Mode mode;
+
+                       mode = _mode_screen_find(root, screenconf[i], outconf[i]);
+                       if (screenconf[i]->config.rotation == 0)
+                         orient = ECORE_X_RANDR_ORIENTATION_ROT_0;
+                       else if (screenconf[i]->config.rotation == 90)
+                         orient = ECORE_X_RANDR_ORIENTATION_ROT_90;
+                       else if (screenconf[i]->config.rotation == 180)
+                         orient = ECORE_X_RANDR_ORIENTATION_ROT_180;
+                       else if (screenconf[i]->config.rotation == 270)
+                         orient = ECORE_X_RANDR_ORIENTATION_ROT_270;
+                       printf("RRR: crtc on: %i = '%s'     @ %i %i    - %ix%i orient %i mode %x out %x\n",
+                              i, screenconf[i]->info.name,
+                              screenconf[i]->config.geom.x,
+                              screenconf[i]->config.geom.y,
+                              screenconf[i]->config.geom.w,
+                              screenconf[i]->config.geom.h,
+                              orient, mode, outconf[i]);
+                       if (!ecore_x_randr_crtc_settings_set
+                             (root, crtcs[i], &(outconf[i]), 1,
+                              screenconf[i]->config.geom.x,
+                              screenconf[i]->config.geom.y,
+                              mode, orient))
+                       printf("RRR:   failed to set crtc!!!!!!\n");
+                       if (E_INSIDE(px, py,
+                                    screenconf[i]->config.geom.x,
+                                    screenconf[i]->config.geom.y,
+                                    screenconf[i]->config.geom.w,
+                                    screenconf[i]->config.geom.h))
+                         fix_pointer = EINA_FALSE;
+                       px = screenconf[i]->config.geom.x +
+                         (screenconf[i]->config.geom.w / 2);
+                       py = screenconf[i]->config.geom.y +
+                         (screenconf[i]->config.geom.h / 2);
+                       ecore_x_randr_crtc_panning_area_set
+                         (root, crtcs[i],
+                          screenconf[i]->config.geom.x,
+                          screenconf[i]->config.geom.y,
+                          screenconf[i]->config.geom.w,
+                          screenconf[i]->config.geom.h);
+                       if (screenconf[i]->config.priority == top_priority)
+                         {
+                            ecore_x_randr_primary_output_set(root, outconf[i]);
+                            top_priority = -1;
+                         }
+                       scrs[scrs_num].x      = screenconf[i]->config.geom.x;
+                       scrs[scrs_num].y      = screenconf[i]->config.geom.y;
+                       scrs[scrs_num].width  = screenconf[i]->config.geom.w;
+                       scrs[scrs_num].height = screenconf[i]->config.geom.h;
+                       scrs_num++;
+                    }
+                  else
+                    {
+                       printf("RRR: crtc off: %i\n", i);
+                       ecore_x_randr_crtc_settings_set
+                         (root, crtcs[i], NULL, 0, 0, 0, 0,
+                          ECORE_X_RANDR_ORIENTATION_ROT_0);
                     }
                }
-             else
-               {
-                  printf("RRR: crtc off: %i\n", i);
-                  ecore_x_randr_crtc_settings_set
-                    (root, crtcs[i], NULL, 0, 0, 0, 0,
-                     ECORE_X_RANDR_ORIENTATION_ROT_0);
-               }
-          }
+             ecore_x_root_screen_barriers_set(scrs, scrs_num);
           }
         else
           {
              printf("RRR: EERRRRRROOOORRRRRRR no outputs to configure!\n");
+             ecore_timer_add(5.0, _cb_no_outputs_timer, NULL);
+             ecore_x_root_screen_barriers_set(NULL, 0);
           }
      }
+   if (fix_pointer)
+     {
+        ecore_x_pointer_warp(root, px, py);
+     }
    free(outputs);
    free(crtcs);
 
@@ -640,7 +684,7 @@ e_comp_x_randr_config_apply(void)
    // ignore the next batch of randr events - we caused them ourselves
    // XXX: a problem. thew first time we configure the screen we may not
    // get any events back to clear the ignore flag below, so only apply
-   // here if the randr config now doesnt match what we want to set up.
+   // here if the randr config now doesn't match what we want to set up.
 //   event_ignore = EINA_TRUE;
 }
 
