@@ -90,8 +90,6 @@ e_desk_new(E_Zone *zone, int x, int y)
    E_Desk *desk;
    Eina_List *l;
    E_Config_Desktop_Name *cfname;
-
-   char name[40];
    int ok = 0;
 
    E_OBJECT_CHECK_RETURN(zone, NULL);
@@ -118,11 +116,7 @@ e_desk_new(E_Zone *zone, int x, int y)
         break;
      }
 
-   if (!ok)
-     {
-        snprintf(name, sizeof(name), "%d,%d", x, y);
-        desk->name = eina_stringshare_add(name);
-     }
+   if (!ok) desk->name = eina_stringshare_add("");
 
    /* Get window profile name for current desktop */
    if (zone->randr2_id)
@@ -209,7 +203,6 @@ e_desk_name_update(void)
    E_Desk *desk;
    E_Config_Desktop_Name *cfname;
    int d_x, d_y, ok;
-   char name[40];
 
    EINA_LIST_FOREACH(e_comp->zones, z, zone)
      {
@@ -231,11 +224,7 @@ e_desk_name_update(void)
                        break;
                     }
 
-                  if (!ok)
-                    {
-                       snprintf(name, sizeof(name), "%d,%d", d_x, d_y);
-                       e_desk_name_set(desk, name);
-                    }
+                  if (!ok) e_desk_name_set(desk, "");
                }
           }
      }
