@@ -84,8 +84,6 @@ e_desklock_shutdown(void)
    if (!x_fatal)
      e_desklock_hide();
 
-//   if (waslocked) e_util_env_set("E_DESKLOCK_LOCKED", "locked");
-
    ecore_event_handler_del(_e_desklock_run_handler);
    _e_desklock_run_handler = NULL;
    ecore_event_handler_del(_e_desklock_randr_handler);
@@ -360,6 +358,7 @@ _desklock_show_internal(Eina_Bool suspend)
    _e_desklock_state = EINA_TRUE;
    e_bindings_disabled_set(1);
    e_screensaver_update();
+   e_dpms_force_update();
    return 1;
 lang_fail:
    if (e_config->desklock_language)
@@ -432,6 +431,7 @@ _desklock_hide_internal(void)
    ecore_event_add(E_EVENT_DESKLOCK, ev, NULL, NULL);
 
    e_screensaver_update();
+   e_dpms_force_update();
 
    if (e_desklock_is_external())
      {
