@@ -707,6 +707,13 @@ _e_desktop_edit_basic_create_widgets(E_Config_Dialog *cfd EINA_UNUSED, Evas *eva
 
    ot = e_widget_table_add(e_win_evas_win_get(evas), 0);
 
+   o = evas_object_rectangle_add(evas);
+   evas_object_color_set(o, 0, 0, 0, 0);
+   evas_object_pass_events_set(o, EINA_TRUE);
+   mw = 200 * e_scale; mh = 80 * e_scale;
+   evas_object_size_hint_min_set(o, mw, mh);
+   e_widget_table_object_append(ot, o, 1, 4, 1, 1, 1, 1, 1, 1);
+
    o = e_widget_label_add(evas, _("Name"));
    e_widget_table_object_append(ot, o, 0, 0, 1, 1, 1, 1, 0, 0);
 
@@ -755,10 +762,16 @@ _e_desktop_edit_basic_create_widgets(E_Config_Dialog *cfd EINA_UNUSED, Evas *eva
 
    ot = e_widget_table_add(e_win_evas_win_get(evas), 0);
 
+   o = evas_object_rectangle_add(evas);
+   evas_object_color_set(o, 0, 0, 0, 0);
+   evas_object_pass_events_set(o, EINA_TRUE);
+   mw = 160 * e_scale; mh = 160 * e_scale;
+   evas_object_size_hint_min_set(o, mw, mh);
+   e_widget_table_object_append(ot, o, 0, 0, 2, 1, 1, 1, 1, 1);
+
    editor->img_widget = e_widget_button_add
        (evas, "", NULL, _e_desktop_editor_cb_icon_select, cfdata, editor);
    _e_desktop_editor_icon_update(cfdata);
-   e_widget_size_min_set(editor->img_widget, 192, 192);
 
    e_widget_table_object_append(ot, editor->img_widget, 0, 0, 2, 1, 1, 1, 1, 1);
 
