@@ -25,6 +25,14 @@ struct _E_Config_Dialog_Data
    } match;
 
    Evas_Object *styles_il;
+   Evas_Object *vsync_check;
+   Evas_Object *texture_check;
+
+   Evas_Object *swap_auto_radio;
+   Evas_Object *swap_full_radio;
+   Evas_Object *swap_copy_radio;
+   Evas_Object *swap_double_radio;
+   Evas_Object *swap_triple_radio;
 
    int          keep_unmapped;
    int          max_unmapped_pixels;
@@ -39,17 +47,7 @@ struct _E_Config_Dialog_Data
    int          fps_corner;
    int          fps_average_range;
    double       first_draw_delay;
-   int disable_screen_effects;
    int enable_advanced_features;
-   // the following options add the "/fast" suffix to the normal groups
-   int fast_popups;
-   int fast_borders;
-   int fast_menus;
-   int fast_overrides;
-   int fast_objects;
-   int fast;
-   Evas_Object *fast_ob;
-   int fast_changed E_BITFIELD;
 };
 
 /* Protos */
@@ -82,7 +80,7 @@ e_int_config_comp(Evas_Object *parent EINA_UNUSED, const char *params EINA_UNUSE
    v->basic.create_widgets = _basic_create_widgets;
    v->advanced.apply_cfdata = _advanced_apply_data;
    v->advanced.create_widgets = _advanced_create_widgets;
-   
+
    cfd = e_config_dialog_new(NULL, _("Composite Settings"),
                              "E", "appearance/comp", "preferences-composite", 0, v, NULL);
    return cfd;
@@ -101,17 +99,6 @@ _create_data(E_Config_Dialog *cfd EINA_UNUSED)
        (cfdata->engine != E_COMP_ENGINE_GL))
      cfdata->engine = E_COMP_ENGINE_SW;
 
-   cfdata->fast_popups = conf->fast_popups;
-   cfdata->fast_borders = conf->fast_borders;
-   cfdata->fast_overrides = conf->fast_overrides;
-   cfdata->fast_menus = conf->fast_menus;
-   cfdata->fast_objects = conf->fast_objects;
-   cfdata->match.disable_popups = conf->match.disable_popups;
-   cfdata->match.disable_borders = conf->match.disable_borders;
-   cfdata->match.disable_overrides = conf->match.disable_overrides;
-   cfdata->match.disable_menus = conf->match.disable_menus;
-   cfdata->match.disable_objects = conf->match.disable_objects;
-   cfdata->disable_screen_effects = conf->disable_screen_effects;
    cfdata->enable_advanced_features = conf->enable_advanced_features;
 
    cfdata->indirect = conf->indirect;
@@ -144,6 +131,39 @@ _create_data(E_Config_Dialog *cfd EINA_UNUSED)
    return cfdata;
 }
 
+static void
+_comp_engine_toggle(void *data, Evas_Object *o EINA_UNUSED, void *event EINA_UNUSED)
+{
+   E_Config_Dialog_Data *cfdata = data;
+
+   e_widget_disabled_set(cfdata->vsync_check,
+                         (cfdata->engine == E_COMP_ENGINE_SW));
+
+   if (cfdata->texture_check)
+     e_widget_disabled_set(cfdata->texture_check,
+                           (cfdata->engine == E_COMP_ENGINE_SW));
+
+   if (cfdata->swap_auto_radio)
+     e_widget_disabled_set(cfdata->swap_auto_radio,
+                           (cfdata->engine == E_COMP_ENGINE_SW));
+
+   if (cfdata->swap_full_radio)
+     e_widget_disabled_set(cfdata->swap_full_radio,
+                           (cfdata->engine == E_COMP_ENGINE_SW));
+
+   if (cfdata->swap_copy_radio)
+     e_widget_disabled_set(cfdata->swap_copy_radio,
+                           (cfdata->engine == E_COMP_ENGINE_SW));
+
+   if (cfdata->swap_double_radio)
+     e_widget_disabled_set(cfdata->swap_double_radio,
+                           (cfdata->engine == E_COMP_ENGINE_SW));
+
+   if (cfdata->swap_triple_radio)
+     e_widget_disabled_set(cfdata->swap_triple_radio,
+                           (cfdata->engine == E_COMP_ENGINE_SW));
+}
+
 static void
 _advanced_features_changed(E_Comp_Config *conf)
 {
@@ -163,12 +183,6 @@ _free_data(E_Config_Dialog *cfd  EINA_UNUSED,
    free(cfdata);
 }
 
-static void
-_advanced_comp_style_toggle(void *oi, Evas_Object *o)
-{
-   e_widget_disabled_set(oi, e_widget_check_checked_get(o));
-}
-
 static void
 _advanced_matches_edit(void *data, void *d EINA_UNUSED)
 {
@@ -203,53 +217,6 @@ _advanced_create_widgets(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data
 
    e_widget_toolbook_page_append(otb, NULL, _("Styles"), ol, 1, 1, 1, 1, 0.5, 0.0);
 
-   //////////////////////////////////////////////
-
-   ol = e_widget_list_add(evas, 0, 0);
-   {
-      Evas_Object *w, *m, *p, *o1, *o2;
-
-      of = e_widget_framelist_add(evas, _("Fast Effects"), 0);
-      w = ob = e_widget_check_add(evas, _("Enable fast composite effects for windows"), &(cfdata->fast_borders));
-      e_widget_disabled_set(ob, cfdata->match.disable_borders);
-      e_widget_framelist_object_append(of, ob);
-      m = ob = e_widget_check_add(evas, _("Enable fast composite effects for menus"), &(cfdata->fast_menus));
-      e_widget_disabled_set(ob, cfdata->match.disable_menus);
-      e_widget_framelist_object_append(of, ob);
-      p = ob = e_widget_check_add(evas, _("Enable fast composite effects for popups"), &(cfdata->fast_popups));
-      e_widget_disabled_set(ob, cfdata->match.disable_popups);
-      e_widget_framelist_object_append(of, ob);
-      o1 = ob = e_widget_check_add(evas, _("Enable fast composite effects for objects"), &(cfdata->fast_objects));
-      e_widget_disabled_set(ob, cfdata->match.disable_objects);
-      e_widget_framelist_object_append(of, ob);
-      o2 = ob = e_widget_check_add(evas, _("Enable fast composite effects for overrides"), &(cfdata->fast_overrides));
-      e_widget_disabled_set(ob, cfdata->match.disable_overrides);
-      e_widget_framelist_object_append(of, ob);
-      e_widget_list_object_append(ol, of, 1, 0, 0.5);
-
-      of = e_widget_framelist_add(evas, _("Disable Effects"), 0);
-      ob = e_widget_check_add(evas, _("Disable composite effects for windows"), &(cfdata->match.disable_borders));
-      e_widget_on_change_hook_set(ob, _advanced_comp_style_toggle, w);
-      e_widget_framelist_object_append(of, ob);
-      ob = e_widget_check_add(evas, _("Disable composite effects for menus"), &(cfdata->match.disable_menus));
-      e_widget_on_change_hook_set(ob, _advanced_comp_style_toggle, m);
-      e_widget_framelist_object_append(of, ob);
-      ob = e_widget_check_add(evas, _("Disable composite effects for popups"), &(cfdata->match.disable_popups));
-      e_widget_on_change_hook_set(ob, _advanced_comp_style_toggle, p);
-      e_widget_framelist_object_append(of, ob);
-      ob = e_widget_check_add(evas, _("Disable composite effects for objects"), &(cfdata->match.disable_objects));
-      e_widget_on_change_hook_set(ob, _advanced_comp_style_toggle, o1);
-      e_widget_framelist_object_append(of, ob);
-      ob = e_widget_check_add(evas, _("Disable composite effects for overrides"), &(cfdata->match.disable_overrides));
-      e_widget_on_change_hook_set(ob, _advanced_comp_style_toggle, o2);
-      e_widget_framelist_object_append(of, ob);
-      ob = e_widget_check_add(evas, _("Disable composite effects for screen"), &(cfdata->disable_screen_effects));
-      e_widget_framelist_object_append(of, ob);
-      e_widget_list_object_append(ol, of, 1, 0, 0.5);
-   }
-
-   e_widget_toolbook_page_append(otb, NULL, _("Effects"), ol, 1, 1, 1, 1, 0.5, 0.0);
-
    ///////////////////////////////////////////
    ol = e_widget_list_add(evas, 0, 0);
    of = e_widget_framelist_add(evas, _("Behavior"), 0);
@@ -267,8 +234,10 @@ _advanced_create_widgets(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data
    of = e_widget_framelist_add(evas, _("Engine"), 0);
    rg = e_widget_radio_group_new(&(cfdata->engine));
    ob = e_widget_radio_add(evas, _("Software"), E_COMP_ENGINE_SW, rg);
+   evas_object_smart_callback_add(ob, "changed", _comp_engine_toggle, cfdata);
    e_widget_framelist_object_append(of, ob);
    ob = e_widget_radio_add(evas, _("OpenGL"), E_COMP_ENGINE_GL, rg);
+   evas_object_smart_callback_add(ob, "changed", _comp_engine_toggle, cfdata);
    e_widget_framelist_object_append(of, ob);
    if ((e_comp->comp_type == E_PIXMAP_TYPE_X) && (!getenv("ECORE_X_NO_XLIB")))
      {
@@ -276,24 +245,48 @@ _advanced_create_widgets(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data
           {
              ob = e_widget_label_add(evas, _("OpenGL options:"));
              e_widget_framelist_object_append(of, ob);
+
              ob = e_widget_check_add(evas, _("Tear-free updates (VSynced)"), &(cfdata->vsync));
              e_widget_framelist_object_append(of, ob);
+             cfdata->vsync_check = ob;
+             e_widget_disabled_set(ob, (cfdata->engine == E_COMP_ENGINE_SW));
+
              ob = e_widget_check_add(evas, _("Texture from pixmap"), &(cfdata->texture_from_pixmap));
              e_widget_framelist_object_append(of, ob);
+             cfdata->texture_check = ob;
+             e_widget_disabled_set(ob, (cfdata->engine == E_COMP_ENGINE_SW));
+
              ob = e_widget_label_add(evas, _("Assume swapping method:"));
              e_widget_framelist_object_append(of, ob);
+
              rg = e_widget_radio_group_new(&(cfdata->swap_mode));
+
              ob = e_widget_radio_add(evas, _("Auto"), ECORE_EVAS_GL_X11_SWAP_MODE_AUTO, rg);
              e_widget_framelist_object_append(of, ob);
+             cfdata->swap_auto_radio = ob;
+             e_widget_disabled_set(ob, (cfdata->engine == E_COMP_ENGINE_SW));
+
              ob = e_widget_radio_add(evas, _("Invalidate (full redraw)"), ECORE_EVAS_GL_X11_SWAP_MODE_FULL, rg);
              e_widget_framelist_object_append(of, ob);
+             cfdata->swap_full_radio = ob;
+             e_widget_disabled_set(ob, (cfdata->engine == E_COMP_ENGINE_SW));
+
              ob = e_widget_radio_add(evas, _("Copy from back to front"), ECORE_EVAS_GL_X11_SWAP_MODE_COPY, rg);
              e_widget_framelist_object_append(of, ob);
+             cfdata->swap_copy_radio = ob;
+             e_widget_disabled_set(ob, (cfdata->engine == E_COMP_ENGINE_SW));
+
              ob = e_widget_radio_add(evas, _("Double buffered swaps"), ECORE_EVAS_GL_X11_SWAP_MODE_DOUBLE, rg);
              e_widget_framelist_object_append(of, ob);
+             cfdata->swap_double_radio = ob;
+             e_widget_disabled_set(ob, (cfdata->engine == E_COMP_ENGINE_SW));
+
              ob = e_widget_radio_add(evas, _("Triple buffered swaps"), ECORE_EVAS_GL_X11_SWAP_MODE_TRIPLE, rg);
              e_widget_framelist_object_append(of, ob);
-// lets not offer this anymore             
+             cfdata->swap_triple_radio = ob;
+             e_widget_disabled_set(ob, (cfdata->engine == E_COMP_ENGINE_SW));
+
+// lets not offer this anymore
 //             ob = e_widget_check_add(evas, _("Indirect OpenGL (EXPERIMENTAL)"), &(cfdata->indirect));
 //             e_widget_framelist_object_append(of, ob);
           }
@@ -328,7 +321,7 @@ _advanced_create_widgets(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data
    e_widget_toolbook_page_append(otb, NULL, _("Misc"), ol, 0, 0, 0, 0, 0.5, 0.0);
 
    ///////////////////////////////////////////
-/*   
+/*
    ol = e_widget_list_add(evas, 0, 0);
    ol2 = e_widget_list_add(evas, 1, 1);
    of = e_widget_framelist_add(evas, _("Min hidden"), 0);
@@ -427,31 +420,9 @@ _advanced_apply_data(E_Config_Dialog *cfd  EINA_UNUSED,
        (cfdata->fps_corner != conf->fps_corner) ||
        (cfdata->fps_average_range != conf->fps_average_range) ||
        (!EINA_DBL_EQ(cfdata->first_draw_delay, conf->first_draw_delay)) ||
-       (conf->match.disable_popups != cfdata->match.disable_popups) ||
-       (conf->match.disable_borders != cfdata->match.disable_borders) ||
-       (conf->match.disable_overrides != cfdata->match.disable_overrides) ||
-       (conf->match.disable_menus != cfdata->match.disable_menus) ||
-       (conf->match.disable_objects != cfdata->match.disable_objects) ||
-       (conf->disable_screen_effects != cfdata->disable_screen_effects) ||
-       (conf->enable_advanced_features != cfdata->enable_advanced_features) ||
-       (conf->fast_popups != cfdata->fast_popups) ||
-       (conf->fast_borders != cfdata->fast_borders) ||
-       (conf->fast_overrides != cfdata->fast_overrides) ||
-       (conf->fast_menus != cfdata->fast_menus) ||
-       (conf->fast_objects != cfdata->fast_objects)
+       (conf->enable_advanced_features != cfdata->enable_advanced_features)
        )
      {
-        conf->fast_popups = cfdata->fast_popups;
-        conf->fast_borders = cfdata->fast_borders;
-        conf->fast_overrides = cfdata->fast_overrides;
-        conf->fast_menus = cfdata->fast_menus;
-        conf->fast_objects = cfdata->fast_objects;
-        conf->match.disable_popups = cfdata->match.disable_popups;
-        conf->match.disable_borders = cfdata->match.disable_borders;
-        conf->match.disable_overrides = cfdata->match.disable_overrides;
-        conf->match.disable_menus = cfdata->match.disable_menus;
-        conf->match.disable_objects = cfdata->match.disable_objects;
-        conf->disable_screen_effects = cfdata->disable_screen_effects;
         if (conf->enable_advanced_features != cfdata->enable_advanced_features)
           _advanced_features_changed(conf);
         conf->lock_fps = cfdata->lock_fps;
@@ -495,20 +466,12 @@ _advanced_apply_data(E_Config_Dialog *cfd  EINA_UNUSED,
    return 1;
 }
 
-static void
-_basic_comp_style_fast_toggle(void *data, Evas_Object *o EINA_UNUSED)
-{
-   E_Config_Dialog_Data *cfdata = data;
-   cfdata->fast_changed = 1;
-}
-
 static void
 _basic_comp_style_toggle(void *data, Evas_Object *o)
 {
    E_Config_Dialog_Data *cfdata = data;
-   
+
    e_widget_disabled_set(cfdata->styles_il, e_widget_check_checked_get(o));
-   e_widget_disabled_set(cfdata->fast_ob, e_widget_check_checked_get(o));
    cfdata->match.toggle_changed = 1;
 }
 
@@ -533,21 +496,6 @@ _basic_create_widgets(E_Config_Dialog *cfd,
 
    ob = e_widget_check_add(evas, _("Don't fade backlight"), &(cfdata->nofade));
    e_widget_list_object_append(ol, ob, 1, 0, 0.5);
-   
-   cfdata->fast =
-     (cfdata->fast_menus && cfdata->fast_overrides && cfdata->fast_borders && cfdata->fast_popups && cfdata->fast_objects);
-   cfdata->fast_ob = ob = e_widget_check_add(evas, _("Enable \"fast\" composite effects"), &(cfdata->fast));
-   evas_object_data_set(ob, "cfdata", cfdata);
-   e_widget_list_object_append(ol, ob, 1, 0, 0.5);
-   e_widget_on_change_hook_set(ob, _basic_comp_style_fast_toggle, cfdata);
-
-   cfdata->match.disable_all =
-     (cfdata->match.disable_menus && cfdata->match.disable_overrides && cfdata->match.disable_borders &&
-      cfdata->match.disable_popups && cfdata->match.disable_objects && cfdata->disable_screen_effects);
-   e_widget_disabled_set(ob, cfdata->match.disable_all);
-   ob = e_widget_check_add(evas, _("Disable composite effects"), &(cfdata->match.disable_all));
-   evas_object_data_set(ob, "cfdata", cfdata);
-   e_widget_list_object_append(ol, ob, 1, 0, 0.5);
 
    of = e_widget_frametable_add(evas, _("Select default style"), 0);
    e_widget_frametable_content_align_set(of, 0.5, 0.5);
@@ -564,9 +512,14 @@ _basic_create_widgets(E_Config_Dialog *cfd,
 
    of = e_widget_framelist_add(evas, _("Behavior"), 0);
 
-   ob = e_widget_check_add(evas, _("Tear-free updates (VSynced)"), &(cfdata->vsync));
-   e_widget_framelist_object_append(of, ob);
-   
+   if (ecore_evas_engine_type_supported_get(ECORE_EVAS_ENGINE_OPENGL_X11))
+     {
+        ob = e_widget_check_add(evas, _("Tear-free updates (VSynced)"), &(cfdata->vsync));
+        e_widget_framelist_object_append(of, ob);
+        cfdata->vsync_check = ob;
+        e_widget_disabled_set(ob, (cfdata->engine == E_COMP_ENGINE_SW));
+     }
+
    ob = e_widget_check_add(evas, _("Smooth scaling of window content"), &(cfdata->smooth_windows));
    e_widget_framelist_object_append(of, ob);
 
@@ -582,11 +535,13 @@ _basic_create_widgets(E_Config_Dialog *cfd,
    rg = e_widget_radio_group_new(&(cfdata->engine));
    ob = e_widget_radio_add(evas, _("Software"), E_COMP_ENGINE_SW, rg);
    e_widget_framelist_object_append(of, ob);
+   evas_object_smart_callback_add(ob, "changed", _comp_engine_toggle, cfdata);
    ob = e_widget_radio_add(evas, _("OpenGL"), E_COMP_ENGINE_GL, rg);
    e_widget_framelist_object_append(of, ob);
+   evas_object_smart_callback_add(ob, "changed", _comp_engine_toggle, cfdata);
 
    e_widget_list_object_append(ol, of, 1, 0, 0.5);
-   
+
    e_widget_toolbook_page_append(otb, NULL, _("Rendering"), ol, 0, 0, 0, 0, 0.5, 0.0);
 
    e_widget_toolbook_page_show(otb, 0);
@@ -602,7 +557,7 @@ _basic_apply_data(E_Config_Dialog *cfd  EINA_UNUSED,
 {
    E_Comp_Config *conf = e_comp_config_get();
 
-   if (cfdata->match.toggle_changed || cfdata->fast_changed ||
+   if (cfdata->match.toggle_changed ||
        (cfdata->lock_fps != conf->lock_fps) ||
        (cfdata->smooth_windows != conf->smooth_windows) ||
        (cfdata->grab != conf->grab) ||
@@ -621,23 +576,6 @@ _basic_apply_data(E_Config_Dialog *cfd  EINA_UNUSED,
        (!EINA_DBL_EQ(cfdata->first_draw_delay, conf->first_draw_delay))
        )
      {
-        if (cfdata->match.toggle_changed)
-          {
-             conf->match.disable_popups = cfdata->match.disable_popups = cfdata->match.disable_all;
-             conf->match.disable_borders = cfdata->match.disable_borders = cfdata->match.disable_all;
-             conf->match.disable_overrides = cfdata->match.disable_overrides = cfdata->match.disable_all;
-             conf->match.disable_menus = cfdata->match.disable_menus = cfdata->match.disable_all;
-             conf->match.disable_objects = cfdata->match.disable_objects = cfdata->match.disable_all;
-             conf->disable_screen_effects = cfdata->disable_screen_effects = cfdata->match.disable_all;
-          }
-        if (cfdata->fast_changed)
-          {
-             conf->fast_borders = cfdata->fast_borders = cfdata->fast;
-             conf->fast_popups = cfdata->fast_popups = cfdata->fast;
-             conf->fast_menus = cfdata->fast_menus = cfdata->fast;
-             conf->fast_objects = cfdata->fast_objects = cfdata->fast;
-             conf->fast_overrides = cfdata->fast_overrides = cfdata->fast;
-          }
         conf->lock_fps = cfdata->lock_fps;
         conf->smooth_windows = cfdata->smooth_windows;
         conf->grab = cfdata->grab;
