@@ -10,7 +10,7 @@ static const char *_names[] = {
    "DBG",
 };
 
-static void
+static void  EINA_PRINTF(6, 0)
 _e_log_cb(const Eina_Log_Domain *d, Eina_Log_Level level, const char *file, const char *fnc EINA_UNUSED, int line, const char *fmt, void *data EINA_UNUSED, va_list args)
 {
    const char *color;
@@ -39,10 +39,8 @@ e_log_init(void)
         if (level < 1)
           eina_log_print_cb_set(_e_log_cb, NULL);
      }
-#ifndef E_RELEASE_BUILD
-   if (!getenv("E_DONT_ABORT"))
+   if (getenv("E_ABORT"))
      eina_log_abort_on_critical_set(1);
-#endif
    return e_log_dom != -1;
 }
 
