@@ -83,6 +83,14 @@ static void         _e_menu_category_free_cb(E_Menu_Category *cat);
 static void         _e_menu_cb_mouse_evas_down(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED);
 static void         _e_menu_hide_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED);
 
+typedef enum
+{
+   NAV_BY_NONE,
+   NAV_BY_MOUSE,
+   NAV_BY_WHEEL,
+   NAV_BY_KEY
+} Nav_By;
+
 /* local subsystem globals */
 static Ecore_Window _e_menu_win = UINT_MAX;
 static Eina_Bool _e_menu_grabbed = EINA_FALSE;
@@ -104,6 +112,7 @@ static int _e_menu_autoscroll_x = 0;
 static int _e_menu_autoscroll_y = 0;
 static Eina_List *handlers = NULL;
 static Eina_Bool _e_menu_lock = EINA_FALSE;
+static Nav_By _e_menu_nav_by = NAV_BY_NONE;
 
 static Eina_Bool pending_feed;
 static unsigned int pending_activate_time;
@@ -245,6 +254,7 @@ e_menu_activate_key(E_Menu *m, E_Zone *zone, int x, int y, int w, int h, int dir
         e_menu_deactivate(m);
         return;
      }
+   _e_menu_nav_by = NAV_BY_KEY;
    switch (dir)
      {
       case E_MENU_POP_DIRECTION_LEFT:
@@ -312,15 +322,19 @@ e_menu_activate_mouse(E_Menu *m, E_Zone *zone, int x, int y, int w, int h, int d
    E_OBJECT_TYPE_CHECK(m, E_MENU_TYPE);
    E_OBJECT_CHECK(zone);
    E_OBJECT_TYPE_CHECK(zone, E_ZONE_TYPE);
-   if (_e_active_menus) e_menu_hide_all();
+
+   e_object_ref(E_OBJECT(m));
+   e_menu_hide_all();
    _e_menu_activate_time = 0;
    _e_menu_activate_floating = 0;
    _e_menu_activate_internal(m, zone);
    if (!m->zone)
      {
         e_menu_deactivate(m);
+        e_object_unref(E_OBJECT(m));
         return;
      }
+   _e_menu_nav_by = NAV_BY_MOUSE;
    switch (dir)
      {
       case E_MENU_POP_DIRECTION_LEFT:
@@ -369,6 +383,7 @@ e_menu_activate_mouse(E_Menu *m, E_Zone *zone, int x, int y, int w, int h, int d
    pending_feed = 1;
    if (!activate_time) activate_time = lround(ecore_loop_time_get() * 1000);
    _e_menu_activate_time = pending_activate_time = activate_time;
+   e_object_unref(E_OBJECT(m));
 }
 
 E_API void
@@ -389,6 +404,7 @@ e_menu_activate(E_Menu *m, E_Zone *zone, int x, int y, int w, int h, int dir)
         e_menu_deactivate(m);
         return;
      }
+   _e_menu_nav_by = NAV_BY_NONE;
    switch (dir)
      {
       case E_MENU_POP_DIRECTION_LEFT:
@@ -443,9 +459,18 @@ e_menu_activate(E_Menu *m, E_Zone *zone, int x, int y, int w, int h, int dir)
 E_API void
 e_menu_deactivate(E_Menu *m)
 {
+   Eina_List *l;
+   E_Menu_Item *mi;
+
    E_OBJECT_CHECK(m);
    E_OBJECT_TYPE_CHECK(m, E_MENU_TYPE);
    if (!m->active) return;
+
+   EINA_LIST_FOREACH(m->items, l, mi)
+     {
+        if (mi->submenu) e_menu_deactivate(mi->submenu);
+     }
+
    m->cur.visible = 0;
    m->active = 0;
    if (m->post_deactivate_cb.func)
@@ -746,6 +771,7 @@ e_menu_item_submenu_set(E_Menu_Item *mi, E_Menu *sub)
    E_OBJECT_CHECK(mi);
    E_OBJECT_TYPE_CHECK(mi, E_MENU_ITEM_TYPE);
 
+   if (mi->submenu == sub) return;
    tmp = _e_active_menus_copy_ref();
    submenu = !!mi->submenu;
    if (mi->submenu) e_object_unref(E_OBJECT(mi->submenu));
@@ -1138,7 +1164,7 @@ e_menu_idler_before(void)
    /* phase 2. move & reisze all the menus that want to moves/resized */
    EINA_LIST_FOREACH(_e_active_menus, l, m)
      {
-        if (m->frozen || (!m->active)) continue;
+        if (m->frozen || (!m->active) || (!m->zone)) continue;
         if (!m->realized) _e_menu_realize(m);
         if (!m->realized) continue;
         if (((m->cur.w) != (m->prev.w)) ||
@@ -1251,7 +1277,7 @@ static void
 _e_menu_dangling_cb(void *data)
 {
    E_Menu *m = data;
-   
+
    WRN("DANGLING SUBMENU: REF(%d)||MENU(%p)", e_object_ref_get(data), data);
    m->dangling_job = NULL;
 }
@@ -1702,6 +1728,7 @@ _e_menu_items_layout_update(E_Menu *m)
    int zh = 0, ms = 0, maxh = 0;
    unsigned int cur_items = 0, max_items = -1;
 
+   if (!m->zone) return;
    EINA_LIST_FOREACH(m->items, l, mi)
      {
         if (mi->icon) icons_on = 1;
@@ -2023,6 +2050,7 @@ _e_menu_reposition(E_Menu *m)
    E_Menu_Item *mi;
    int parent_item_bottom;
 
+   if (!m->zone) return;
    if (!m->parent_item) return;
    m->cur.x = m->parent_item->menu->cur.x + m->parent_item->menu->cur.w;
 
@@ -2037,14 +2065,12 @@ _e_menu_reposition(E_Menu *m)
         else
           /* more is shown if menu goes down */
           m->cur.y = parent_item_bottom - m->zone->y;
-#endif        
+#endif
      }
    else
      {
-        /* menu is smaller than screen */
-        if (((parent_item_bottom + m->cur.h) > (m->zone->y + m->zone->h)) &&
-            (parent_item_bottom > (m->zone->y + (m->zone->h / 2))))
-          /* menu is partially out of screen and more is shown if menu goes up */
+        /* menu is on top or bottom half of screen */
+        if (parent_item_bottom > (m->zone->y + (m->zone->h / 2)))
           m->cur.y = parent_item_bottom - m->cur.h + m->parent_item->h;
         else
           m->cur.y = parent_item_bottom;
@@ -2448,6 +2474,7 @@ _e_menu_outside_bounds_get(int xdir, int ydir)
 
    EINA_LIST_FOREACH(_e_active_menus, l, m)
      {
+        if (!m->zone) continue;
         if (m->cur.x < m->zone->x + e_config->menu_autoscroll_margin)
           {
              i = m->zone->x - m->cur.x + e_config->menu_autoscroll_margin;
@@ -2514,7 +2541,7 @@ _e_menu_mouse_autoscroll_check(void)
    if (_e_active_menus)
      {
         m = eina_list_data_get(_e_active_menus);
-        if (m)
+        if ((m) && (m->zone))
           {
              mx -= m->zone->x;
              my -= m->zone->y;
@@ -2530,7 +2557,7 @@ _e_menu_mouse_autoscroll_check(void)
      }
    if ((!autoscroll_x) && (!autoscroll_y))
      {
-        if (m)
+        if ((m) && (m->zone))
           {
              if (mx + e_config->menu_autoscroll_cursor_margin >= (m->zone->w - 1))
                {
@@ -2577,6 +2604,7 @@ _e_menu_auto_place_vert(E_Menu *m, int x, int y, int w, int h)
 {
    int zx, zy, zw, zh;
 
+   if (!m->zone) return;
    e_zone_useful_geometry_get(m->zone, &zx, &zy, &zw, &zh);
    if (E_CONTAINS(zx, zy, zw, zh, m->cur.x, y, m->cur.w, m->cur.h))
      {
@@ -2610,6 +2638,7 @@ _e_menu_auto_place(E_Menu *m, int x, int y, int w, int h)
     *
     * quadrants... which one
     */
+   if (!m->zone) return 0;
    if (w != m->zone->w)
      xr = (double)(x - m->zone->x) /
        (double)(m->zone->w - w);
@@ -2674,6 +2703,8 @@ _e_menu_cb_item_in(void *data, Evas *evas EINA_UNUSED, Evas_Object *obj EINA_UNU
    E_Menu_Item *mi = data;
 
    if (_e_menu_lock) return;
+   // ignore in/out not due to deliberate mouse move by user
+   if (_e_menu_nav_by != NAV_BY_MOUSE) return;
    /* this can be triggered when creating menus if the new menu is on top of its parent */
    if (!mi->menu->realized) return;
    e_menu_item_active_set(mi, 1);
@@ -2683,6 +2714,8 @@ static void
 _e_menu_cb_item_out(void *data, Evas *evas EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    E_Menu_Item *mi = data;
+   // ignore in/out not due to deliberate mouse move by user
+   if (_e_menu_nav_by != NAV_BY_MOUSE) return;
    /* this can be triggered when creating menus if the new menu is on top of its parent */
    if (!mi->menu->realized) return;
    e_menu_item_active_set(mi, 0);
@@ -2691,6 +2724,7 @@ _e_menu_cb_item_out(void *data, Evas *evas EINA_UNUSED, Evas_Object *obj EINA_UN
 static Eina_Bool
 _e_menu_cb_key_down(void *data EINA_UNUSED, Ecore_Event_Key *ev)
 {
+   _e_menu_nav_by = NAV_BY_KEY;
    if ((!strcmp(ev->key, "Up")) || (!strcmp(ev->key, "KP_Up")))
      _e_menu_item_activate_previous();
    else if ((!strcmp(ev->key, "Down")) || (!strcmp(ev->key, "KP_Down")))
@@ -2758,6 +2792,7 @@ _e_menu_cb_mouse_down(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
    Ecore_Event_Mouse_Button *ev;
 
    ev = event;
+   _e_menu_nav_by = NAV_BY_MOUSE;
    if (ev->window != _e_menu_win)
      {
         if (_e_menu_active_get())
@@ -2793,6 +2828,7 @@ _e_menu_cb_mouse_up(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
    ev = event;
    if (ev->window != _e_menu_win) return ECORE_CALLBACK_RENEW;
 
+   _e_menu_nav_by = NAV_BY_MOUSE;
    if (!_e_menu_activate_floating)
      {
         EINA_LIST_FOREACH(_e_active_menus, l, m)
@@ -2859,6 +2895,7 @@ _e_menu_cb_mouse_move(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
 
    ev = event;
    if (ev->window != _e_menu_win) return ECORE_CALLBACK_PASS_ON;
+   _e_menu_nav_by = NAV_BY_MOUSE;
    fast_move_threshold = e_config->menus_fast_mouse_move_threshhold;
    dx = ev->x - _e_menu_x;
    dy = ev->y - _e_menu_y;
@@ -2927,6 +2964,7 @@ _e_menu_cb_mouse_wheel(void *data EINA_UNUSED, int type EINA_UNUSED, void *event
 
    ev = event;
    if (ev->window != _e_menu_win) return ECORE_CALLBACK_PASS_ON;
+   _e_menu_nav_by = NAV_BY_WHEEL;
    if (ev->z < 0) /* up */
      {
         int i;
@@ -2997,13 +3035,8 @@ _e_menu_cb_scroll_animator(void *data EINA_UNUSED)
 static void
 _e_menu_cb_item_submenu_post_default(void *data EINA_UNUSED, E_Menu *m EINA_UNUSED, E_Menu_Item *mi)
 {
-   E_Menu *subm;
-
    if (!mi->submenu) return;
-
-   subm = mi->submenu;
-   e_menu_item_submenu_set(mi, NULL);
-   e_object_del(E_OBJECT(subm));
+   e_menu_item_submenu_set(mi, NULL); // unis unrefs previous submenu
 }
 
 static void
