@@ -52,7 +52,11 @@ e_mouse_update(void)
 
         dev = ecore_evas_data_get(e_comp->ee, "device");
         if (dev)
-          ecore_drm2_device_pointer_left_handed_set(dev, (Eina_Bool)!e_config->mouse_hand);
+          {
+             ecore_drm2_device_pointer_left_handed_set(dev, (Eina_Bool)!e_config->mouse_hand);
+             ecore_drm2_device_pointer_accel_speed_set(dev, e_config->mouse_accel_numerator);
+             ecore_drm2_device_touch_tap_to_click_enabled_set(dev, e_config->touch_tap_to_click);
+          }
      }
 #endif
    return 1;
