@@ -135,6 +135,11 @@ handler_find(const char *mime)
         eina_stringshare_del(name);
      }
 
+   if (!desktop)
+     {
+        if (!strcmp(mime, "inode/directory"))
+          desktop = efreet_util_desktop_file_id_find("enlightenment_filemanager.desktop");
+     }
    if (!desktop)
      desktop = desktop_first_free_others(efreet_util_desktop_mime_list(mime));
 
@@ -438,7 +443,7 @@ static const struct type_mime
    /* {"browser", "x-scheme-handler/http"}, */
    {"mail", "x-scheme-handler/mailto"},
    /*  {"terminal", NULL}, */
-   {"filemanager", "x-scheme-handler/file"},
+   {"filemanager", "inode/directory"},
    {"image", "image/jpeg"},
    {"video", "video/x-mpeg"},
    {"music", "audio/mp3"},
@@ -475,6 +480,20 @@ static const Ecore_Getopt options = {
    }
 };
 
+static Eina_Bool
+_is_protocol(const char *path)
+{
+    Eina_Bool nonlocal = EINA_FALSE;
+    const char *p = path;
+    while (!nonlocal && *p && *p != '/')
+    {
+       nonlocal = (*p == ':');
+       p++;
+    }
+   return nonlocal;
+}
+
+
 E_API int
 main(int argc, char *argv[])
 {
@@ -535,7 +554,7 @@ main(int argc, char *argv[])
                }
           }
      }
-   else if (strstr(argv[args], ":"))
+   else if (_is_protocol(argv[args]))
      cmds = protocol_open(argv[args]);
    else
      cmds = local_open(argv[args]);
