@@ -5,6 +5,7 @@
 /////////////////////////////////////////////////////////////////////////
 static Eina_Bool               _screen_closed(E_Randr2_Screen *s);
 static void                    _animated_apply_abort(void);
+static void                    _cb_delay_init_save(void *data);
 static Eina_Bool               _cb_delay_timer(void *data);
 static Eina_Bool               _cb_fade_animator(void *data);
 static void                    _animated_apply(void);
@@ -40,6 +41,12 @@ E_API E_Randr2        *e_randr2 = NULL;
 
 E_API int              E_EVENT_RANDR_CHANGE = 0;
 
+static void
+_cb_delay_init_save(void *data EINA_UNUSED)
+{
+   e_randr2_config_save();
+}
+
 /////////////////////////////////////////////////////////////////////////
 EINTERN Eina_Bool
 e_randr2_init(void)
@@ -105,7 +112,7 @@ e_randr2_init(void)
    else
      {
         _config_update(e_randr2, e_randr2_cfg, 0);
-        e_randr2_config_save();
+        ecore_job_add(_cb_delay_init_save, NULL);
      }
    ecore_event_add(E_EVENT_RANDR_CHANGE, NULL, NULL, NULL);
    return EINA_TRUE;
@@ -637,7 +644,7 @@ _screens_differ(E_Randr2 *r1, E_Randr2 *r2)
    EINA_LIST_FOREACH(r2->screens, l, s)
      {
         if (!s->id) continue;
-        EINA_LIST_FOREACH(r2->screens, ll, ss)
+        EINA_LIST_FOREACH(r1->screens, ll, ss)
           {
              if ((ss->id) && (!strcmp(s->id, ss->id))) break;
              ss = NULL;
@@ -712,7 +719,7 @@ _cb_screen_change_delay(void *data EINA_UNUSED)
    Eina_Bool change = EINA_FALSE;
    _screen_delay_timer = NULL;
    printf("RRR: ... %i %i\n", event_screen, event_ignore);
-   // if we had a screen plug/unplug etc. event and we shouldnt ignore it...
+   // if we had a screen plug/unplug etc. event and we shouldn't ignore it...
    if ((event_screen) && (!event_ignore))
      {
         Eina_List *l;
@@ -720,6 +727,7 @@ _cb_screen_change_delay(void *data EINA_UNUSED)
         int lid_screens = 0;
         int close_lid_screens = 0;
         int external_screens = 0;
+        int prev_external_screens = 0;
         E_Randr2 *rtemp;
 
         printf("RRR: reconfigure screens due to event...\n");
@@ -738,19 +746,41 @@ _cb_screen_change_delay(void *data EINA_UNUSED)
                }
              EINA_LIST_FOREACH(rtemp->screens, l, s)
                {
+                  printf("RRR: scr: %s lid=%i conn=%i\n", s->id, s->info.is_lid, s->info.connected);
 //                  if (!s->id) continue;
                   if (s->info.is_lid)
                     {
+                       printf("RRR: is lid, lid++\n");
                        lid_screens++;
-                       if (s->info.lid_closed) close_lid_screens++;
+                       if (s->info.lid_closed)
+                         {
+                            printf("RRR: is lid, is closed, closed++\n");
+                            close_lid_screens++;
+                         }
                     }
                   else
                     {
-                       if ((s->info.connected) && (s->config.enabled))
-                         external_screens++;
+                       if (s->info.connected)
+                         {
+                            printf("RRR: is not lid, is connected, ext++\n");
+                            external_screens++;
+                         }
+                       else
+                         {
+                            printf("RRR: is not lid, is not connected\n");
+                         }
                     }
                }
-             printf("RRR: lids=%i closed=%i ext=%i\n", lid_screens, close_lid_screens, external_screens);
+             EINA_LIST_FOREACH(e_randr2->screens, l, s)
+               {
+                  printf("RRR: prev_scr: %s lid=%i conn=%i\n", s->id, s->info.is_lid, s->info.connected);
+//                  if (!s->id) continue;
+                  if (!s->info.is_lid)
+                    {
+                       if (s->info.connected) prev_external_screens++;
+                    }
+               }
+             printf("RRR: lids=%i closed=%i ext=%i prev_ext=%i\n", lid_screens, close_lid_screens, external_screens, prev_external_screens);
              _info_free(rtemp);
           }
         printf("RRR: change = %i\n", change);
@@ -759,7 +789,7 @@ _cb_screen_change_delay(void *data EINA_UNUSED)
         if (change)
           {
              if ((lid_screens > 0) && (close_lid_screens == lid_screens) &&
-                 (external_screens == 0))
+                 (external_screens == 0) && (external_screens == prev_external_screens))
                {
                   printf("RRR: skip change with all lids closed and no ext\n");
                   change = EINA_FALSE;
@@ -774,7 +804,7 @@ _cb_screen_change_delay(void *data EINA_UNUSED)
                   // force dpms...
                }
              if ((lid_screens > 0) && (close_lid_screens < lid_screens) &&
-                 (external_screens == 0))
+                 (external_screens == 0) && (external_screens == prev_external_screens))
                {
                   printf("RRR: skip change with lid screens open and no ext\n");
                   change = EINA_FALSE;
@@ -1463,6 +1493,7 @@ e_randr2_screen_id_find(const char *id)
    Eina_List *l;
    E_Randr2_Screen *s;
 
+   if (!id) return NULL;
    EINA_LIST_FOREACH(e_randr2->screens, l, s)
      {
         if (!strcmp(id, s->id)) return s;
