@@ -31,8 +31,6 @@
 extern char **environ;
 #endif
 
-double e_sys_l2ping(const char *bluetooth_mac, int timeout_ms);
-
 /* local subsystem functions */
 #ifdef HAVE_EEZE_MOUNT
 static Eina_Bool mountopts_check(const char *opts);
@@ -61,12 +59,10 @@ main(int argc,
    int i, gn;
    int test = 0;
    char *action = NULL, *cmd;
-   char *output = NULL, *param = NULL;
 #ifdef HAVE_EEZE_MOUNT
    Eina_Bool mnt = EINA_FALSE;
    const char *act = NULL;
 #endif
-   Eina_Bool rfkill = EINA_FALSE;
    gid_t gid, gl[65536], egid;
 
    for (i = 1; i < argc; i++)
@@ -89,24 +85,6 @@ main(int argc,
              test = 1;
              action = argv[2];
           }
-        else if (!strcmp(argv[1], "l2ping"))
-          {
-             action = argv[1];
-             output = argv[2];
-             if (argc >= 4) param = argv[3];
-          }
-        else if (!strcmp(argv[1], "rfkill-unblock"))
-          {
-             rfkill = EINA_TRUE;
-             action = argv[1];
-             output = argv[2];
-          }
-        else if (!strcmp(argv[1], "rfkill-block"))
-          {
-             rfkill = EINA_TRUE;
-             action = argv[1];
-             output = argv[2];
-          }
 #ifdef HAVE_EEZE_MOUNT
         else
           {
@@ -172,22 +150,6 @@ main(int argc,
         exit(20);
      }
 
-   if (!test && !strcmp(action, "l2ping"))
-     {
-        char tmp[128];
-        double latency;
-        int timeout = 10 * 1000;
-
-        if (param) timeout = atoi(param);
-        if (timeout < 1) timeout = 1;// min timeout 1ms
-        else if (timeout > (60 * 60 * 1000)) timeout = 60 * 60 * 1000;// max 1h
-        latency = e_sys_l2ping(output, timeout);
-
-        eina_convert_dtoa(latency, tmp);
-        fputs(tmp, stdout);
-
-        return (latency < 0) ? 1 : 0;
-     }
    /* sanitize environment */
 #ifdef HAVE_UNSETENV
 # define NOENV(x) unsetenv(x)
@@ -299,59 +261,6 @@ main(int argc,
    putenv("PATH=/bin:/usr/bin:/sbin:/usr/sbin");
    putenv("IFS= \t\n");
 
-   if ((!test) && (rfkill))
-     {
-        Eina_Strbuf *buf = NULL;
-        const char *s;
-
-        buf = eina_strbuf_new();
-        if (!buf) exit(30);
-        for (s = output; *s; s++)
-          {
-             if (!(((*s >= 'a') && (*s <= 'z')) ||
-                   ((*s >= 'A') && (*s <= 'Z')) ||
-                   ((*s >= '0') && (*s <= '9')) ||
-                   (*s == '-') || (*s == '+') || (*s == ',') || (*s == '.') ||
-                   (*s == '/') || (*s == ':') || (*s == '=') || (*s == '@') ||
-                   (*s == '^')))
-               break;
-          }
-        if (*s == 0)
-          {
-             char *rfk = strdup(cmd);
-             if (rfk)
-               {
-                  char *pc = strchr(rfk, ' ');
-                  if (pc)
-                    {
-                       *pc = 0;
-                       FILE *p = popen(rfk, "r");
-                       if (p)
-                         {
-                            char lin[1024];
-                            char dev[1024];
-                            int id = -1;
-
-                            while (fgets(lin, sizeof(lin), p))
-                              {
-                                 lin[sizeof(lin) - 1] = 0;
-                                 if (sscanf(lin, "%i %*s %s %*s %*s", &id, dev) != 2)
-                                   id = -1;
-                                 else
-                                   {
-                                      if (!strcmp(dev, output)) break;
-                                   }
-                              }
-                            pclose(p);
-                            eina_strbuf_append_printf(buf, "%s %i", cmd, id);
-                            return system(eina_strbuf_string_get(buf));
-                         }
-                    }
-               }
-          }
-        exit(30);
-     }
-
    if ((!test)
 #ifdef HAVE_EEZE_MOUNT
        && (!mnt)
