@@ -75,12 +75,12 @@ static void  _e_wid_fprev_preview_fm(E_Widget_Data *wd);
 static void
 _e_wid_fprev_preview_update(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
-   E_Widget_Data *wd;
+   E_Widget_Data *wd = data;
    Evas_Object *o;
    char buf[256];
    int iw = 0, ih = 0;
 
-   wd = data;
+   if (!wd->o_preview_extra) return;
    if (evas_object_image_extension_can_load_get(wd->path))
      {
         o = evas_object_image_add(evas_object_evas_get(obj));
@@ -204,9 +204,6 @@ _e_wid_fprev_clear_widgets(E_Widget_Data *wd)
 #define CLRWID(xx) \
   do { if (wd->xx) { evas_object_del(wd->xx); wd->xx = NULL; } } while (0)
 
-   CLRWID(o_preview_preview_table);
-   CLRWID(o_preview_properties_table);
-   CLRWID(o_preview_scroll);
    CLRWID(o_preview_extra);
    CLRWID(o_preview_extra_entry);
    CLRWID(o_preview_size);
@@ -222,6 +219,9 @@ _e_wid_fprev_clear_widgets(E_Widget_Data *wd)
    CLRWID(o_preview_preview);
    CLRWID(o_preview_scrollframe);
    CLRWID(o_preview_artwork);
+   CLRWID(o_preview_scroll);
+   CLRWID(o_preview_preview_table);
+   CLRWID(o_preview_properties_table);
    wd->is_dir = wd->is_txt = wd->is_font = wd->prev_is_fm = wd->prev_is_video = EINA_FALSE;
    wd->vid_pct = 0;
 
@@ -387,8 +387,10 @@ _e_wid_fprev_preview_video_widgets(E_Widget_Data *wd)
    if (wd->o_preview_artwork)
      {
         if (mime && !strncmp(mime, "audio/",6))
-          e_widget_size_min_set(table, 192, 190);
-        evas_object_image_filled_set(wd->o_preview_artwork, EINA_TRUE);
+          e_widget_size_min_set(table, 192, 192);
+	evas_object_resize(wd->o_preview_artwork, 256, 256);
+	evas_object_image_fill_set(wd->o_preview_artwork, 0, 0, 256, 256);
+	evas_object_size_hint_max_set(wd->o_preview_artwork, 256, 256);
         e_widget_table_object_append(wd->o_preview_properties_table,
                                      wd->o_preview_artwork, 0, 0, 2, 2, 1, 1, 1, 1);
         evas_object_show(wd->o_preview_artwork);
@@ -644,7 +646,7 @@ _e_wid_fprev_preview_file(E_Widget_Data *wd)
                          {
                             if (statvfs(mpoint, &stfs) != 0) ok = EINA_FALSE;
                          }
-                       
+
                        fragsz = stfs.f_frsize;
                        blknum = stfs.f_blocks;
                        blkused = stfs.f_blocks - stfs.f_bfree;
@@ -1133,7 +1135,7 @@ _e_wid_fprev_preview_font(E_Widget_Data *wd)
              buf = alloca(strlen(escaped) + 4096);
              snprintf(buf, strlen(wd->path) + 4096,
                       "<font=%s>"
-                      
+
                       "<font_size=28>"
                       "28 - ABC abc 0123 @!?#$*{}<ps/>"
                       "The quick brown fox jumps.<ps/>"
@@ -1141,19 +1143,19 @@ _e_wid_fprev_preview_font(E_Widget_Data *wd)
                       "<font_size=20>"
                       "20 - ABC abc 0123 @!?#$*{}<ps/>"
                       "The quick brown fox jumps.<ps/>"
-                      
+
                       "<font_size=16>"
                       "16 - ABC abc 0123 @!?#$*{}<ps/>"
                       "The quick brown fox jumps.<ps/>"
-                      
+
                       "<font_size=12>"
                       "12 - ABC abc 0123 @!?#$*{}<ps/>"
                       "The quick brown fox jumps.<ps/>"
-                      
+
                       "<font_size=10>"
                       "10 - ABC abc 0123 @!?#$*{}<ps/>"
                       "The quick brown fox jumps.<ps/>"
-                      
+
                       "<font_size=8>"
                       "8 - ABC abc 0123 @!?#$*{}<ps/>"
                       "The quick brown fox jumps.<ps/>"
