@@ -1,6 +1,7 @@
 #include "bz.h"
 #include "e_mod_main.h"
 
+static Eldbus_Object *objman_obj = NULL;
 static Eldbus_Proxy *objman_proxy = NULL;
 static Eldbus_Signal_Handler *sig_ifadd = NULL;
 static Eldbus_Signal_Handler *sig_ifdel = NULL;
@@ -194,10 +195,10 @@ cb_obj_prop_entry(void *data, const void *key, Eldbus_Message_Iter *var)
    // dict ServiceData [readonly, optional]
    //  Service advertisement data. Keys are the UUIDs in
    //  string format followed by its byte array value.
-   // 
+   //
    // array{byte} AdvertisingFlags [readonly, experimental]
    //  The Advertising Data Flags of the remote device.
-   // 
+   //
    // dict AdvertisingData [readonly, experimental]
    //  The Advertising Data of the remote device. Keys are
    //  are 8 bits AD Type followed by data as byte array.
@@ -295,18 +296,16 @@ cb_obj_prop_changed(void *data EINA_UNUSED, const Eldbus_Message *msg EINA_UNUSE
 Obj *
 bz_obj_add(const char *path)
 {
-   Eldbus_Object *obj;
-
    Obj *o = calloc(1, sizeof(Obj));
    o->ref = 1;
    o->path = eina_stringshare_add(path);
-   obj = eldbus_object_get(bz_conn, "org.bluez", o->path);
+   o->obj = eldbus_object_get(bz_conn, "org.bluez", o->path);
    o->type = BZ_OBJ_UNKNOWN;
    o->in_table = EINA_TRUE;
    eina_hash_add(obj_table, o->path, o);
    if (!strcmp(o->path, "/org/bluez"))
      {
-        o->proxy = eldbus_proxy_get(obj, "org.bluez.AgentManager1");
+        o->proxy = eldbus_proxy_get(o->obj, "org.bluez.AgentManager1");
         o->type = BZ_OBJ_BLUEZ;
         o->add_called = EINA_TRUE;
         bz_obj_ref(o);
@@ -317,12 +316,12 @@ bz_obj_add(const char *path)
    // all devices are /org/bluez/XXX/dev_XXX so look for /dev_
    else if (strstr(o->path, "/dev_"))
      {
-        o->proxy = eldbus_proxy_get(obj, "org.bluez.Device1");
+        o->proxy = eldbus_proxy_get(o->obj, "org.bluez.Device1");
         o->type = BZ_OBJ_DEVICE;
         if (o->proxy)
           {
              eldbus_proxy_property_get_all(o->proxy, cb_obj_prop, o);
-             o->prop_proxy = eldbus_proxy_get(obj,
+             o->prop_proxy = eldbus_proxy_get(o->obj,
                                               "org.freedesktop.DBus.Properties");
              if (o->prop_proxy)
                o->prop_sig = eldbus_proxy_signal_handler_add(o->prop_proxy,
@@ -334,19 +333,19 @@ bz_obj_add(const char *path)
    // all dadapters begin with /org/bluez/
    else if (!strncmp(o->path, "/org/bluez/", 11))
      {
-        o->proxy = eldbus_proxy_get(obj, "org.bluez.Adapter1");
+        o->proxy = eldbus_proxy_get(o->obj, "org.bluez.Adapter1");
         o->type = BZ_OBJ_ADAPTER;
         if (o->proxy)
           {
              eldbus_proxy_property_get_all(o->proxy, cb_obj_prop, o);
-             o->prop_proxy = eldbus_proxy_get(obj,
+             o->prop_proxy = eldbus_proxy_get(o->obj,
                                               "org.freedesktop.DBus.Properties");
              if (o->prop_proxy)
                o->prop_sig = eldbus_proxy_signal_handler_add(o->prop_proxy,
                                                              "PropertiesChanged",
                                                              cb_obj_prop_changed, o);
              // disable the filter for discovery later
-             // XXX: this doesnt seem to exist on the bluez daemons i see
+             // XXX: this doesn't seem to exist on the bluez daemons I see
              // so don't do this to avoid error noise and it's useless it seems
              // eldbus_proxy_call
              //  (o->proxy, "SetDiscoveryFilter", cb_obj_discovery_filter, o, -1, "");
@@ -538,35 +537,42 @@ bz_obj_disconnect(Obj *o)
      (o->proxy, "Disconnect", cb_disconnect, o, -1, "");
 }
 
-static Eina_Bool
-cb_ping_exit(void *data, int type EINA_UNUSED, void *event)
+static void
+_cb_l2ping(void *data, const char *params)
 {
    Obj *o = data;
-   Ecore_Exe_Event_Del *ev = event;
+   char addr[256];
+   int timeout = 0;
 
-   printf("@@@EXE EXIT.. %p == %p\n", ev->exe, o->ping_exe);
-   if (ev->exe != o->ping_exe) return ECORE_CALLBACK_PASS_ON;
-   printf("@@@PING RESULT... %i\n", ev->exit_code);
-   o->ping_exe = NULL;
-   if (ev->exit_code == 0)
+   if (sscanf(params, "%255s %i", addr, &timeout) == 2)
      {
-        if (!o->ping_ok)
+        if (!strcmp(o->address, addr))
           {
-             printf("@@@PING SUCCEED\n");
-             o->ping_ok = EINA_TRUE;
-             if (o->fn_change) o->fn_change(o);
+             if (o->ping_busy)
+               {
+                  e_system_handler_del("l2ping-ping", _cb_l2ping, o);
+                  o->ping_busy = EINA_FALSE;
+               }
+             if (timeout >= 0)
+               {
+                  if (!o->ping_ok)
+                    {
+                       printf("@@@PING SUCCEED\n");
+                       o->ping_ok = EINA_TRUE;
+                       if (o->fn_change) o->fn_change(o);
+                    }
+               }
+             else
+               {
+                  if (o->ping_ok)
+                    {
+                       printf("@@@PING FAIL\n");
+                       o->ping_ok = EINA_FALSE;
+                       if (o->fn_change) o->fn_change(o);
+                    }
+               }
           }
      }
-   else
-     {
-        if (o->ping_ok)
-          {
-             printf("@@@PING FAIL\n");
-             o->ping_ok = EINA_FALSE;
-             if (o->fn_change) o->fn_change(o);
-          }
-     }
-   return ECORE_CALLBACK_PASS_ON;
 }
 
 static int
@@ -585,24 +591,13 @@ ping_powersave_timeout_get(void)
 static void
 ping_do(Obj *o)
 {
-   Eina_Strbuf *buf;
-
-   if (!o->ping_exe_handler)
-     o->ping_exe_handler = ecore_event_handler_add(ECORE_EXE_EVENT_DEL,
-                                                   cb_ping_exit, o);
-   buf = eina_strbuf_new();
-   if (buf)
-     {
-        int timeout = ping_powersave_timeout_get();
-
-        timeout *= 1000;
-        eina_strbuf_append_printf
-          (buf, "%s/enlightenment/utils/enlightenment_sys l2ping %s %i",
-           e_prefix_lib_get(), o->address, timeout);
-        o->ping_exe = ecore_exe_run(eina_strbuf_string_get(buf), NULL);
-        eina_strbuf_free(buf);
-        printf("@@@ run new ping %s %i = %p\n", o->address, timeout, o->ping_exe);
-     }
+   int timeout = 1000 * ping_powersave_timeout_get();
+   if (o->ping_busy)
+     e_system_handler_del("l2ping-ping", _cb_l2ping, o);
+   o->ping_busy = EINA_TRUE;
+   e_system_handler_add("l2ping-ping", _cb_l2ping, o);
+   e_system_send("l2ping-ping", "%s %i", o->address, timeout);
+   printf("@@@ run new ping %s %i\n", o->address, timeout);
 }
 
 static Eina_Bool cb_ping_timer(void *data);
@@ -622,11 +617,10 @@ cb_ping_timer(void *data)
    Obj *o = data;
 
    printf("@@@ ping timer %s\n", o->address);
-   if (o->ping_exe)
+   if (o->ping_busy)
      {
-        printf("@@@PING TIMEOUT\n");
-        ecore_exe_free(o->ping_exe);
-        o->ping_exe = NULL;
+        o->ping_busy = EINA_FALSE;
+        e_system_handler_del("l2ping-ping", _cb_l2ping, o);
         if (o->ping_ok)
           {
              o->ping_ok = EINA_FALSE;
@@ -642,15 +636,10 @@ void
 bz_obj_ping_begin(Obj *o)
 {
    if (o->ping_timer) return;
-   if (o->ping_exe_handler)
+   if (o->ping_busy)
      {
-        ecore_event_handler_del(o->ping_exe_handler);
-        o->ping_exe_handler = NULL;
-     }
-   if (o->ping_exe)
-     {
-        ecore_exe_free(o->ping_exe);
-        o->ping_exe = NULL;
+        o->ping_busy = EINA_FALSE;
+        e_system_handler_del("l2ping-ping", _cb_l2ping, o);
      }
    ping_do(o);
    ping_schedule(o);
@@ -659,20 +648,15 @@ bz_obj_ping_begin(Obj *o)
 void
 bz_obj_ping_end(Obj *o)
 {
-   if (o->ping_exe_handler)
-     {
-        ecore_event_handler_del(o->ping_exe_handler);
-        o->ping_exe_handler = NULL;
-     }
    if (o->ping_timer)
      {
         ecore_timer_del(o->ping_timer);
         o->ping_timer = NULL;
      }
-   if (o->ping_exe)
+   if (o->ping_busy)
      {
-        ecore_exe_free(o->ping_exe);
-        o->ping_exe = NULL;
+        o->ping_busy = EINA_FALSE;
+        e_system_handler_del("l2ping-ping", _cb_l2ping, o);
      }
    if (o->ping_ok)
      {
@@ -736,22 +720,17 @@ bz_obj_unref(Obj *o)
         o->in_table = EINA_FALSE;
         eina_hash_del(obj_table, o->path, o);
      }
+   if (o->ping_busy)
+     {
+        o->ping_busy = EINA_FALSE;
+        e_system_handler_del("l2ping-ping", _cb_l2ping, o);
+     }
    _obj_clear(o);
    if (o->prop_sig)
      {
         eldbus_signal_handler_del(o->prop_sig);
         o->prop_sig = NULL;
      }
-   if (o->proxy)
-     {
-        eldbus_proxy_unref(o->proxy);
-        o->proxy = NULL;
-     }
-   if (o->prop_proxy)
-     {
-        eldbus_proxy_unref(o->prop_proxy);
-        o->prop_proxy = NULL;
-     }
    if (o->path)
      {
         eina_stringshare_del(o->path);
@@ -772,20 +751,25 @@ bz_obj_unref(Obj *o)
         bz_agent_msg_drop(o->agent_msg_ok);
         o->agent_msg_ok = NULL;
      }
-   if (o->ping_exe_handler)
-     {
-        ecore_event_handler_del(o->ping_exe_handler);
-        o->ping_exe_handler = NULL;
-     }
    if (o->ping_timer)
      {
         ecore_timer_del(o->ping_timer);
         o->ping_timer = NULL;
      }
-   if (o->ping_exe)
+   if (o->proxy)
      {
-        ecore_exe_free(o->ping_exe);
-        o->ping_exe = NULL;
+        eldbus_proxy_unref(o->proxy);
+        o->proxy = NULL;
+     }
+   if (o->prop_proxy)
+     {
+        eldbus_proxy_unref(o->prop_proxy);
+        o->prop_proxy = NULL;
+     }
+   if (o->obj)
+     {
+        eldbus_object_unref(o->obj);
+        o->obj = NULL;
      }
    free(o);
 }
@@ -894,12 +878,10 @@ _obj_hash_free(Obj *o)
 void
 bz_obj_init(void)
 {
-   Eldbus_Object *obj;
-
    obj_table = eina_hash_string_superfast_new((void *)_obj_hash_free);
 
-   obj = eldbus_object_get(bz_conn, "org.bluez", "/");
-   objman_proxy = eldbus_proxy_get(obj, "org.freedesktop.DBus.ObjectManager");
+   objman_obj = eldbus_object_get(bz_conn, "org.bluez", "/");
+   objman_proxy = eldbus_proxy_get(objman_obj, "org.freedesktop.DBus.ObjectManager");
    sig_ifadd = eldbus_proxy_signal_handler_add(objman_proxy, "InterfacesAdded",
                                                cb_obj_add, NULL);
    sig_ifdel = eldbus_proxy_signal_handler_add(objman_proxy, "InterfacesRemoved",
@@ -928,8 +910,16 @@ bz_obj_shutdown(void)
         eldbus_signal_handler_del(sig_ifdel);
         sig_ifdel = NULL;
      }
-   eldbus_proxy_unref(objman_proxy);
-   objman_proxy = NULL;
+   if (objman_proxy)
+     {
+        eldbus_proxy_unref(objman_proxy);
+        objman_proxy = NULL;
+     }
+   if (objman_obj)
+     {
+        eldbus_object_unref(objman_obj);
+        objman_obj = NULL;
+     }
 }
 
 void
