@@ -55,16 +55,17 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    Evas *e;
    Evas_Coord w = 320, h = 240, mw = 0, mh = 0;
    Eina_List *objs = NULL;
-   Evas_Object *o, *po, *po2, *po3, *win;
+   Evas_Object *o, *po, *po2, *po3, *win, *parent;
 
    _e_int_theme_preview_clear(preview);
    e = e_widget_preview_evas_get(preview);
-   win = e_win_evas_win_get(e);
+   parent = e_win_evas_win_get(e);
+   win = parent;
    if (!win)
      win = elm_win_fake_add(ecore_evas_ecore_evas_get(e));
    evas_object_size_hint_min_get(preview, &w, &h);
    w *= 2; h *= 2;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/desktop/background");
    evas_object_move(o, 0, 0);
@@ -81,7 +82,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    edje_object_signal_emit(o, "e,state,visible,on", "e");
    objs = eina_list_append(objs, o);
    po = o;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/shelf/default/base");
    evas_object_show(o);
@@ -90,16 +91,16 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    objs = eina_list_append(objs, o);
    po = o;
    po2 = po;
-   
+
    o = elm_box_add(win);
    elm_box_horizontal_set(o, 1);
    evas_object_show(o);
    edje_object_part_swallow(po, "e.swallow.content", o);
    objs = eina_list_append(objs, o);
    po = o;
-   
+
    mh = 42 * e_scale;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/modules/start/main");
    evas_object_show(o);
@@ -123,7 +124,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    edje_object_part_swallow(po2, "e.swallow.content", o);
    objs = eina_list_append(objs, o);
    po3 = o;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/modules/pager/desk");
    evas_object_show(o);
@@ -176,7 +177,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    elm_box_pack_end(po, o);
    evas_object_size_hint_min_set(o, mh, 0);
    objs = eina_list_append(objs, o);
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/modules/clock/main");
    evas_object_show(o);
@@ -184,8 +185,8 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    elm_box_pack_end(po, o);
    evas_object_size_hint_min_set(o, mh, 0);
    objs = eina_list_append(objs, o);
-   
-   
+
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/comp/frame/default");
    evas_object_move(o, w / 2, h / 9);
@@ -197,7 +198,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    objs = eina_list_append(objs, o);
    po = o;
    po2 = po;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/widgets/border/default/border");
    edje_object_part_text_set(o, "e.text.title", "Title");
@@ -206,7 +207,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    edje_object_part_swallow(po, "e.swallow.content", o);
    objs = eina_list_append(objs, o);
    po = o;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/theme/about");
    edje_object_size_min_get(o, &mw, &mh);
@@ -217,9 +218,9 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    edje_object_part_swallow(po, "e.swallow.client", o);
    objs = eina_list_append(objs, o);
 
-   
-   
-   
+
+
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/comp/frame/default");
    evas_object_move(o, w / 10, h / 5);
@@ -230,7 +231,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    edje_object_signal_emit(o, "e,state,focus,on", "e");
    objs = eina_list_append(objs, o);
    po = o;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/widgets/border/default/border");
    edje_object_part_text_set(o, "e.text.title", "Title");
@@ -239,7 +240,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    edje_object_part_swallow(po, "e.swallow.content", o);
    objs = eina_list_append(objs, o);
    po = o;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/widgets/dialog/main");
    evas_object_show(o);
@@ -248,10 +249,10 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    objs = eina_list_append(objs, o);
    po = o;
    po2 = po;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/widgets/dialog/text");
-   edje_object_part_text_set(o, "e.textblock.message", 
+   edje_object_part_text_set(o, "e.textblock.message",
                              "<hilight>Welcome to enlightenment.</hilight><ps/>"
                              "<ps/>"
                              "This is a sample set of content for a<ps/>"
@@ -259,7 +260,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    evas_object_show(o);
    edje_object_part_swallow(po, "e.swallow.content", o);
    objs = eina_list_append(objs, o);
-   
+
    o = e_icon_add(e);
    e_util_icon_theme_set(o, "dialog-warning");
    evas_object_show(o);
@@ -274,7 +275,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    edje_object_part_swallow(po, "e.swallow.buttons", o);
    objs = eina_list_append(objs, o);
    po = o;
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/widgets/button");
    evas_object_show(o);
@@ -284,7 +285,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    elm_box_pack_end(po, o);
    evas_object_size_hint_min_set(o, 50, 20);
    objs = eina_list_append(objs, o);
-   
+
    o = edje_object_add(e);
    _e_int_theme_edje_file_set(o, file, "e/widgets/button");
    evas_object_show(o);
@@ -301,7 +302,7 @@ _e_int_theme_preview_set(Evas_Object *preview, const char *file)
    edje_object_part_swallow(po2, "e.swallow.buttons", po);
 
    evas_object_data_set(preview, "objects", objs);
-   
+
 //   e_widget_preview_edje_set(preview, file, "e/desktop/background");
    return EINA_TRUE;
 }
@@ -515,6 +516,30 @@ _cb_files_files_deleted(void *data, Evas_Object *obj EINA_UNUSED, void *event_in
    evas_object_smart_callback_call(cfdata->o_fm, "selection_change", cfdata);
 }
 
+static void
+_cb_import_online(void *data1 EINA_UNUSED, void *data2 EINA_UNUSED)
+{
+   Efreet_Desktop *desktop;
+   E_Zone *zone;
+
+   desktop = efreet_util_desktop_file_id_find("extra.desktop");
+   if (!desktop)
+   {
+      e_util_dialog_internal
+         (_("Missing Application"),
+         _("This module wants to execute an external application<ps/> "
+            "that does not exist.<ps/>"
+            "Please install <b>extra</b> application.<ps/>"
+            "https://git.enlightenment.org/apps/extra.git/"));
+      return;
+   }
+
+   zone = e_zone_current_get();
+
+   e_exec(zone, desktop, NULL, NULL, "extra/app");
+   efreet_desktop_free(desktop);
+}
+
 static void
 _cb_import(void *data1, void *data2 EINA_UNUSED)
 {
@@ -677,17 +702,19 @@ _free_data(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
 static Evas_Object *
 _basic_create_widgets(E_Config_Dialog *cfd EINA_UNUSED, Evas *evas, E_Config_Dialog_Data *cfdata)
 {
-   Evas_Object *o, *ot, *of, *il, *ol;
+   Evas_Object *o, *ot, *of, *il, *ol, *parent;
    E_Zone *z;
    E_Radio_Group *rg;
    char path[PATH_MAX];
 
+   parent = e_win_evas_win_get(evas);
+
    z = e_zone_current_get();
    e_dialog_resizable_set(cfd->dia, 1);
 
-   ot = e_widget_table_add(e_win_evas_win_get(evas), 0);
-   ol = e_widget_table_add(e_win_evas_win_get(evas), 0);
-   il = e_widget_table_add(e_win_evas_win_get(evas), 1);
+   ot = e_widget_table_add(parent, 0);
+   ol = e_widget_table_add(parent, 0);
+   il = e_widget_table_add(parent, 0);
 
    rg = e_widget_radio_group_new(&(cfdata->fmdir));
    o = e_widget_radio_add(evas, _("Personal"), 0, rg);
@@ -698,13 +725,13 @@ _basic_create_widgets(E_Config_Dialog *cfd EINA_UNUSED, Evas *evas, E_Config_Dia
    cfdata->o_system = o;
    evas_object_smart_callback_add(o, "changed", _cb_dir, cfdata);
    e_widget_table_object_append(il, o, 1, 0, 1, 1, 1, 1, 0, 0);
-
-   e_widget_table_object_append(ol, il, 0, 0, 1, 1, 0, 0, 0, 0);
-
-   o = e_widget_button_add(evas, _("Go up a Directory"), "go-up",
+      o = e_widget_button_add(evas, _("Go up a Directory"), "go-up",
                            _cb_button_up, cfdata, NULL);
    cfdata->o_up_button = o;
-   e_widget_table_object_append(ol, o, 0, 1, 1, 1, 0, 0, 0, 0);
+   e_widget_table_object_append(il, o, 2, 0, 1, 1, 1, 1, 0, 0);
+
+   e_widget_table_object_align_append(ol, il, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0);
+
 
    if (cfdata->fmdir == 1)
      snprintf(path, sizeof(path), "%s", elm_theme_system_dir_get());
@@ -733,24 +760,32 @@ _basic_create_widgets(E_Config_Dialog *cfd EINA_UNUSED, Evas *evas, E_Config_Dia
 
    e_widget_size_min_set(o, 160, 160);
    e_widget_table_object_append(ol, o, 0, 2, 1, 1, 1, 1, 1, 1);
-   e_widget_table_object_append(ot, ol, 0, 0, 1, 1, 1, 1, 1, 1);
+   e_widget_table_object_append(ot, ol, 0, 0, 1, 1, 1, 1, 0, 1);
 
    of = e_widget_list_add(evas, 0, 0);
 
-   il = e_widget_list_add(evas, 0, 1);
+   il = e_widget_table_add(evas, 0);
 
-   o = e_widget_button_add(evas, _(" Import..."), "preferences-desktop-theme",
+   o = e_widget_button_add(evas, _(" Import File..."), "preferences-desktop-theme",
                            _cb_import, cfdata, NULL);
-   e_widget_list_object_append(il, o, 1, 0, 0.5);
+   e_widget_table_object_align_append(il, o, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0);
+
+   if (efreet_util_desktop_file_id_find("extra.desktop"))
+   {
+      o = e_widget_button_add(evas, _(" Import Online..."), "preferences-desktop-theme",
+                              _cb_import_online, NULL, NULL);
+      e_widget_table_object_align_append(il, o, 1, 0, 1, 1, 0, 0, 1, 0, 0, 0);
+   }
+
    o = e_widget_check_add(evas, _("Show startup splash"), &cfdata->show_splash);
-   e_widget_list_object_append(il, o, 1, 0, 0.5);
-   e_widget_list_object_append(of, il, 1, 0, 0.0);
+   e_widget_table_object_align_append(il, o, 2, 0, 1, 1, 0, 0, 1, 0, 0, 0);
+   e_widget_list_object_append(of, il, 0, 0, 0.0);
 
    {
       Evas_Object *oa;
       int mw, mh;
 
-      mw = 320;
+      mw = 500;
       mh = (mw * z->h) / z->w;
       oa = e_widget_aspect_add(evas, mw, mh);
       o = e_widget_preview_add(evas, mw, mh);
