@@ -464,7 +464,7 @@ bool econnman_service_remove(struct Connman_Service *cs,
             cs->pending.disconnect, cs->pending.remov);
         return false;
      }
-   
+
    cd = calloc(1, sizeof(*cd));
    EINA_SAFETY_ON_NULL_GOTO(cd, fail);
 
@@ -813,7 +813,7 @@ static void _manager_powered_cb(void *data, const Eldbus_Message *msg,
    Eldbus_Pending *p;
    struct Connman_Manager *cm = data;
    const char *error_name, *error_msg;
-   
+
    cm->pending.set_powered = NULL;
 
    if (eldbus_message_error_get(msg, &error_name, &error_msg))
@@ -871,7 +871,7 @@ static struct Connman_Manager *_manager_new(void)
                                   _manager_services_changed, cm);
    eldbus_proxy_signal_handler_add(cm->technology_iface, "PropertyChanged",
                                   _manager_wifi_prop_changed, cm);
-   
+
    /*
     * PropertyChanged signal in service's path is guaranteed to arrive only
     * after ServicesChanged above. So we only add the handler later, in a per
@@ -891,7 +891,7 @@ static struct Connman_Manager *_manager_new(void)
    return cm;
 }
 
-static inline void _e_connman_system_name_owner_exit(void)
+static inline void _e_connman_system_name_owner_exit(Eina_Bool shutdown)
 {
    if (!connman_manager)
      return;
@@ -901,6 +901,10 @@ static inline void _e_connman_system_name_owner_exit(void)
    connman_manager = NULL;
 
    ecore_event_add(E_CONNMAN_EVENT_MANAGER_OUT, NULL, NULL, NULL);
+   if (!shutdown)
+     e_util_dialog_show(_("Connman Service Missing"),
+                        _("The Connman service is not able to be found.<br>"
+                          "Is <b>connmand</b> daemon running?"));
 }
 
 static inline void _e_connman_system_name_owner_enter(const char *owner EINA_UNUSED)
@@ -920,7 +924,7 @@ _e_connman_system_name_owner_changed(void *data EINA_UNUSED,
    if (to[0])
      _e_connman_system_name_owner_enter(to);
    else
-     _e_connman_system_name_owner_exit();
+     _e_connman_system_name_owner_exit(EINA_FALSE);
 }
 
 /**
@@ -929,7 +933,7 @@ _e_connman_system_name_owner_changed(void *data EINA_UNUSED,
  * This will connect to ConnMan through DBus and watch for it going in and out.
  *
  * Interesting events are:
- *   - E_CONNMAN_EVENT_MANAGER_IN: issued when connman is avaiable.
+ *   - E_CONNMAN_EVENT_MANAGER_IN: issued when connman is available.
  *   - E_CONNMAN_EVENT_MANAGER_OUT: issued when connman connection is lost.
  */
 unsigned int
@@ -974,7 +978,7 @@ e_connman_system_shutdown(void)
    eldbus_name_owner_changed_callback_del(conn, CONNMAN_BUS_NAME,
                                          _e_connman_system_name_owner_changed,
                                          NULL);
-   _e_connman_system_name_owner_exit();
+   _e_connman_system_name_owner_exit(EINA_TRUE);
    if (agent)
      econnman_agent_del(agent);
    if (conn)
