@@ -40,7 +40,9 @@ struct _Smart_Data
 
    double              last_select;
    double              scroll_align;
+   double              scroll_align_from;
    double              scroll_align_to;
+   double              animator_start;
    Ecore_Animator     *animator;
 
    int                 slide_offset;
@@ -502,13 +504,13 @@ _e_smart_reconfigure_do(void *data)
         sd->idle_enter = NULL;
         return ECORE_CALLBACK_CANCEL;
      }
-   
+
    if (sd->view->hiding)
      {
         sd->idle_enter = NULL;
         return ECORE_CALLBACK_CANCEL;
      }
-   
+
    if (sd->cx > (sd->cw - sd->w)) sd->cx = sd->cw - sd->w;
    if (sd->cy > (sd->ch - sd->h)) sd->cy = sd->ch - sd->h;
    if (sd->cx < 0) sd->cx = 0;
@@ -756,25 +758,20 @@ _animator(void *data)
 {
    Smart_Data *sd = evas_object_smart_data_get(data);
    if (!sd) return ECORE_CALLBACK_CANCEL;
-
    double da;
-   double spd = ((25.0 / (double)e_config->framerate) /
-                 (double)(1 + sd->view->zoom));
-   if (spd > 0.9) spd = 0.9;
-
+   double pos = (ecore_loop_time_get() - sd->animator_start) / 0.2;
    int wait = 0;
 
+   if (pos < 0.0) pos = 0.0;
+   else if (pos > 1.0) pos = 1.0;
    if (!EINA_DBL_EQ(sd->scroll_align, sd->scroll_align_to))
      {
-        sd->scroll_align = ((sd->scroll_align * (1.0 - spd)) +
-                            (sd->scroll_align_to * spd));
-
+        sd->scroll_align = ((sd->scroll_align_from * (1.0 - pos)) +
+                            (sd->scroll_align_to * pos));
         da = sd->scroll_align - sd->scroll_align_to;
         if (da < 0.0) da = -da;
-        if (da < 0.02)
-          sd->scroll_align = sd->scroll_align_to;
-        else
-          wait++;
+        if (da < 0.02) sd->scroll_align = sd->scroll_align_to;
+        else wait++;
 
         e_scrollframe_child_pos_set(sd->view->sframe,
                                     0, sd->scroll_align);
@@ -868,7 +865,11 @@ _pan_item_select(Evas_Object *obj, Item *it, int scroll)
         sd->scroll_align_to = align;
 
         if ((!EINA_DBL_EQ(align, sd->cy)) && !sd->animator)
-          sd->animator = ecore_animator_add(_animator, obj);
+          {
+             sd->animator_start = ecore_loop_time_get();
+             sd->scroll_align_from = sd->scroll_align;
+             sd->animator = ecore_animator_add(_animator, obj);
+          }
      }
    else
      {
@@ -957,9 +958,9 @@ _update_frame(Evas_Object *obj)
         ecore_idle_enterer_del(sd->idle_enter);
         sd->idle_enter = NULL;
      }
-   
+
    sd->place = EINA_TRUE;
-   
+
    _e_smart_reconfigure_do(obj);
 
    _pan_item_select(obj, sd->cur_item, 0);
@@ -1470,7 +1471,7 @@ _view_cb_mouse_wheel(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *o
      }
 }
 
-// FIXME: 'drag into' make mouse input hang after some trials 
+// FIXME: 'drag into' make mouse input hang after some trials
 #if 0
 static void
 _view_cb_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
@@ -1525,7 +1526,7 @@ _view_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSE
         edje_object_signal_emit(sd->view->bg, "e,action,hide,back", "e");
         goto end;
      }
-   
+
    if ((sel->states->next) || (sel != sel->win->selectors[0]))
      edje_object_signal_emit(sd->view->bg, "e,action,show,back", "e");
 
