@@ -3,69 +3,64 @@
 #define MUSIC_CONTROL_DOMAIN "module.music_control"
 
 static E_Module *music_control_mod = NULL;
-
 static Eina_Bool was_playing_before_lock = EINA_FALSE;
-
 static const char _e_music_control_Name[] = N_("Music controller");
+static Eina_Bool have_player = EINA_FALSE;
 
 const Player music_player_players[] =
 {
-   {"gmusicbrowser", "org.mpris.MediaPlayer2.gmusicbrowser"},
-   {"Banshee", "org.mpris.MediaPlayer2.banshee"},
-   {"Clementine", "org.mpris.MediaPlayer2.clementine"},
-   {"Audacious", "org.mpris.MediaPlayer2.audacious"},
-   {"VLC", "org.mpris.MediaPlayer2.vlc"},
-   {"BMP", "org.mpris.MediaPlayer2.bmp"},
-   {"XMMS2", "org.mpris.MediaPlayer2.xmms2"},
-   {"DeaDBeeF", "org.mpris.MediaPlayer2.deadbeef"},
-   {"Rhythmbox", "org.gnome.Rhythmbox3"},
-   {"Quod Libet", "org.mpris.MediaPlayer2.quodlibet"},
-   {"MPD", "org.mpris.MediaPlayer2.mpd"},
-   {"Emotion Media Center", "org.mpris.MediaPlayer2.epymc"},
-   {"Pithos", "org.mpris.MediaPlayer2.pithos"},
-   {"Tomahawk", "org.mpris.MediaPlayer2.tomahawk"},
-   {"Spotify", "org.mpris.MediaPlayer2.spotify"},
-   {"Rage", "org.mpris.MediaPlayer2.rage"},
-   {NULL, NULL}
+    // Label/Name           dbus iface name                         command to execute
+   {"Audacious",            "org.mpris.MediaPlayer2.audacious",        "audacious"},
+   {"BMP",                  "org.mpris.MediaPlayer2.bmp",              "bmp"},
+   {"Banshee",              "org.mpris.MediaPlayer2.banshee",          "banshee"},
+   {"Clementine",           "org.mpris.MediaPlayer2.clementine",       "clementine"},
+   {"DeaDBeeF",             "org.mpris.MediaPlayer2.deadbeef",         "deadbeef"},
+   {"Emotion Media Center", "org.mpris.MediaPlayer2.epymc",            "epymc"},
+   {"MPD",                  "org.mpris.MediaPlayer2.mpd",              "mpd"},
+   {"Pithos",               "org.mpris.MediaPlayer2.io.github.Pithos", "pithos"},
+   {"Quod Libet",           "org.mpris.MediaPlayer2.quodlibet",        "quodlibet"},
+   {"Rage",                 "org.mpris.MediaPlayer2.rage",             "rage"},
+   {"Rhythmbox",            "org.gnome.Rhythmbox3",                    "rhythmbox"},
+   {"Spotify",              "org.mpris.MediaPlayer2.spotify",          "spotify"},
+   {"Tomahawk",             "org.mpris.MediaPlayer2.tomahawk",         "tomahawk"},
+   {"VLC",                  "org.mpris.MediaPlayer2.vlc",              "vlc"},
+   {"XMMS2",                "org.mpris.MediaPlayer2.xmms2",            "xmms2"},
+   {"gmusicbrowser",        "org.mpris.MediaPlayer2.gmusicbrowser",    "gmusicbrowser"},
+#define PLAYER_COUNT 16
+   {NULL, NULL, NULL}
 };
 
 Eina_Bool
 _desklock_cb(void *data, int type EINA_UNUSED, void *ev)
 {
-   E_Music_Control_Module_Context *ctxt;
-   E_Event_Desklock *event;
+   E_Music_Control_Module_Context *ctxt = data;
+   E_Event_Desklock *event = ev;
 
-   ctxt = data;
-   event = ev;
-
-   /* Lock with music on. Pause it */
+   // Lock with music on. Pause it
    if (event->on && ctxt->playing)
      {
         media_player2_player_play_pause_call(ctxt->mpris2_player);
         was_playing_before_lock = EINA_TRUE;
         return ECORE_CALLBACK_PASS_ON;
      }
-
-   /* Lock without music. Keep music off as state */
+   // Lock without music. Keep music off as state
    if (event->on && (!ctxt->playing))
      {
         was_playing_before_lock = EINA_FALSE;
         return ECORE_CALLBACK_PASS_ON;
      }
-
-   /* Unlock with music pause and playing before lock. Turn it back on */
+   // Unlock with music pause and playing before lock. Turn it back on
    if ((!event->on) && (!ctxt->playing) && was_playing_before_lock)
      media_player2_player_play_pause_call(ctxt->mpris2_player);
-
    return ECORE_CALLBACK_PASS_ON;
 }
 
 static void
 _music_control(E_Object *obj EINA_UNUSED, const char *params)
 {
-   E_Music_Control_Module_Context *ctxt;
+   E_Music_Control_Module_Context *ctxt = music_control_mod->data;
    EINA_SAFETY_ON_NULL_RETURN(music_control_mod->data);
-   ctxt = music_control_mod->data;
+
    if (!strcmp(params, "play"))
      media_player2_player_play_pause_call(ctxt->mpris2_player);
    else if (!strcmp(params, "next"))
@@ -85,23 +80,20 @@ static void
 _actions_register(E_Music_Control_Module_Context *ctxt)
 {
    E_Action *action;
-   if (ctxt->actions_set) return;
 
+   if (ctxt->actions_set) return;
    action = e_action_add(ACTION_NEXT);
    action->func.go = _music_control;
    e_action_predef_name_set(_e_music_control_Name, ACTION_NEXT_NAME,
                             ACTION_NEXT, "next", NULL, 0);
-
    action = e_action_add(ACTION_PLAY_PAUSE);
    action->func.go = _music_control;
    e_action_predef_name_set(_e_music_control_Name, ACTION_PLAY_PAUSE_NAME,
                             ACTION_PLAY_PAUSE, "play", NULL, 0);
-
    action = e_action_add(ACTION_PREVIOUS);
    action->func.go = _music_control;
    e_action_predef_name_set(_e_music_control_Name, ACTION_PREVIOUS_NAME,
                             ACTION_PREVIOUS, "previous", NULL, 0);
-
    ctxt->actions_set = EINA_TRUE;
 }
 
@@ -115,7 +107,6 @@ _actions_unregister(E_Music_Control_Module_Context *ctxt)
    e_action_del(ACTION_PLAY_PAUSE);
    e_action_predef_name_del(ACTION_PREVIOUS_NAME, ACTION_PREVIOUS);
    e_action_del(ACTION_PREVIOUS);
-
    ctxt->actions_set = EINA_FALSE;
 }
 
@@ -134,15 +125,13 @@ _gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
    inst->gadget = edje_object_add(gc->evas);
    e_theme_edje_object_set(inst->gadget, "base/theme/modules/music-control",
                            "e/modules/music-control/main");
-
    inst->gcc = e_gadcon_client_new(gc, name, id, style, inst->gadget);
    inst->gcc->data = inst;
 
-   evas_object_event_callback_add(inst->gadget, EVAS_CALLBACK_MOUSE_DOWN, music_control_mouse_down_cb, inst);
-
+   evas_object_event_callback_add(inst->gadget, EVAS_CALLBACK_MOUSE_DOWN,
+                                  music_control_mouse_down_cb, inst);
    ctxt->instances = eina_list_append(ctxt->instances, inst);
    _actions_register(ctxt);
-
    return inst->gcc;
 }
 
@@ -153,16 +142,12 @@ _gc_shutdown(E_Gadcon_Client *gcc)
    E_Music_Control_Module_Context *ctxt;
 
    EINA_SAFETY_ON_NULL_RETURN(music_control_mod);
-
    ctxt = music_control_mod->data;
    inst = gcc->data;
-
    evas_object_del(inst->gadget);
    if (inst->popup) music_control_popup_del(inst);
    ctxt->instances = eina_list_remove(ctxt->instances, inst);
-   if (!ctxt->instances)
-     _actions_unregister(ctxt);
-
+   if (!ctxt->instances) _actions_unregister(ctxt);
    free(inst);
 }
 
@@ -199,7 +184,6 @@ _gc_id_new(const E_Gadcon_Client_Class *client_class EINA_UNUSED)
    E_Music_Control_Module_Context *ctxt;
    EINA_SAFETY_ON_NULL_RETURN_VAL(music_control_mod, NULL);
    ctxt = music_control_mod->data;
-
    snprintf(tmpbuf, sizeof(tmpbuf), "music-control.%d",
             eina_list_count(ctxt->instances));
    return tmpbuf;
@@ -207,8 +191,7 @@ _gc_id_new(const E_Gadcon_Client_Class *client_class EINA_UNUSED)
 
 static const E_Gadcon_Client_Class _gc_class =
 {
-   GADCON_CLIENT_CLASS_VERSION, "music-control",
-   {
+   GADCON_CLIENT_CLASS_VERSION, "music-control", {
       _gc_init, _gc_shutdown, _gc_orient, _gc_label, _gc_icon, _gc_id_new, NULL,
       e_gadcon_site_is_not_toolbar
    },
@@ -227,7 +210,6 @@ parse_metadata(E_Music_Control_Module_Context *ctxt, Eina_Value *array)
    E_FREE_FUNC(ctxt->meta_artist, eina_stringshare_del);
    E_FREE_FUNC(ctxt->meta_cover, eina_stringshare_del);
    // DBG("Metadata: %s", eina_value_to_string(array));
-
    for (i = 0; i < eina_value_array_count(array); i++)
      {
         const char *key, *str_val;
@@ -291,14 +273,13 @@ cb_playback_status_get(void *data, Eldbus_Pending *p EINA_UNUSED,
 
    if (error_info)
      {
-        fprintf(stderr, "MUSIC-CONTROL: %s %s", error_info->error, error_info->message);
+        fprintf(stderr, "MUSIC-CONTROL: %s %s",
+                error_info->error, error_info->message);
         return;
      }
 
-   if (!strcmp(value, "Playing"))
-     ctxt->playing = EINA_TRUE;
-   else
-     ctxt->playing = EINA_FALSE;
+   if (!strcmp(value, "Playing")) ctxt->playing = EINA_TRUE;
+   else ctxt->playing = EINA_FALSE;
    music_control_state_update_all(ctxt);
 }
 
@@ -325,10 +306,8 @@ prop_changed(void *data, Eldbus_Proxy *proxy EINA_UNUSED, void *event_info)
         const char *status;
 
         eina_value_get(value, &status);
-        if (!strcmp(status, "Playing"))
-          ctxt->playing = EINA_TRUE;
-        else
-          ctxt->playing = EINA_FALSE;
+        if (!strcmp(status, "Playing")) ctxt->playing = EINA_TRUE;
+        else ctxt->playing = EINA_FALSE;
         music_control_state_update_all(ctxt);
      }
    else if (!strcmp(event->name, "Metadata"))
@@ -339,36 +318,88 @@ prop_changed(void *data, Eldbus_Proxy *proxy EINA_UNUSED, void *event_info)
 }
 
 static void
-cb_name_owner_has(void *data, const Eldbus_Message *msg,
-                  Eldbus_Pending *pending EINA_UNUSED)
+cb_name_owner_changed(void *data,
+                      const char *bus EINA_UNUSED,
+                      const char *from EINA_UNUSED,
+                      const char *to)
 {
    E_Music_Control_Module_Context *ctxt = data;
-   Eina_Bool owner_exists;
 
-   if (eldbus_message_error_get(msg, NULL, NULL))
-     return;
-   if (!eldbus_message_arguments_get(msg, "b", &owner_exists))
-     return;
-   if (owner_exists)
+   have_player = EINA_FALSE;
+   if (to[0])
      {
-        media_player2_player_playback_status_propget(ctxt->mpris2_player,
-                                                  cb_playback_status_get, ctxt);
-        media_player2_player_metadata_propget(ctxt->mpris2_player,
-                                              cb_metadata_get, ctxt);
+        media_player2_player_playback_status_propget
+          (ctxt->mpris2_player, cb_playback_status_get, ctxt);
+        media_player2_player_metadata_propget
+          (ctxt->mpris2_player, cb_metadata_get, ctxt);
+        have_player = EINA_TRUE;
+     }
+}
+
+void
+music_control_launch(E_Music_Control_Instance *inst)
+{
+   E_Music_Control_Module_Context *ctxt;
+
+   if (!music_control_mod) return;
+   ctxt = music_control_mod->data;
+   if (have_player) return;
+   if (ctxt->config->player_selected < 0)
+     {
+        Efreet_Desktop *desktop;
+        int i;
+
+        for (i = 0; i < PLAYER_COUNT; i++)
+          {
+             desktop = efreet_util_desktop_exec_find
+               (music_player_players[i].command);
+             if (desktop)
+               {
+                  E_Zone *zone = e_gadcon_zone_get(inst->gcc->gadcon);
+                  e_exec(zone, desktop, NULL/* command */,
+                         NULL/* file list */, "module/music-control");
+                  ctxt->config->player_selected = i;
+                  music_control_dbus_init
+                    (ctxt, music_player_players[i].dbus_name);
+                  break;
+               }
+          }
+     }
+   else if (ctxt->config->player_selected < PLAYER_COUNT)
+     {
+        E_Zone *zone = e_gadcon_zone_get(inst->gcc->gadcon);
+        e_exec(zone, NULL/* efreet desktop*/,
+               music_player_players[ctxt->config->player_selected].command,
+               NULL/* file list */, "module/music-control");
      }
 }
 
 Eina_Bool
 music_control_dbus_init(E_Music_Control_Module_Context *ctxt, const char *bus)
 {
-   ctxt->conn = eldbus_connection_get(ELDBUS_CONNECTION_TYPE_SESSION);
+   if (!ctxt->conn)
+     ctxt->conn = eldbus_connection_get(ELDBUS_CONNECTION_TYPE_SESSION);
    EINA_SAFETY_ON_NULL_RETURN_VAL(ctxt->conn, EINA_FALSE);
 
+   if (ctxt->mpris2_player)
+     mpris_media_player2_proxy_unref(ctxt->mpris2_player);
+   if (ctxt->mrpis2)
+     media_player2_player_proxy_unref(ctxt->mrpis2);
    ctxt->mrpis2 = mpris_media_player2_proxy_get(ctxt->conn, bus, NULL);
    ctxt->mpris2_player = media_player2_player_proxy_get(ctxt->conn, bus, NULL);
-   eldbus_proxy_event_callback_add(ctxt->mpris2_player, ELDBUS_PROXY_EVENT_PROPERTY_CHANGED,
-                                  prop_changed, ctxt);
-   eldbus_name_owner_has(ctxt->conn, bus, cb_name_owner_has, ctxt);
+   eldbus_proxy_event_callback_add(ctxt->mpris2_player,
+                                   ELDBUS_PROXY_EVENT_PROPERTY_CHANGED,
+                                   prop_changed, ctxt);
+   if (ctxt->dbus_name)
+     {
+        eldbus_name_owner_changed_callback_del
+          (ctxt->conn, ctxt->dbus_name, cb_name_owner_changed, ctxt);
+        eina_stringshare_del(ctxt->dbus_name);
+     }
+   ctxt->dbus_name = eina_stringshare_add(bus);
+   eldbus_name_owner_changed_callback_add(ctxt->conn, bus,
+                                          cb_name_owner_changed,
+                                          ctxt, EINA_TRUE);
    return EINA_TRUE;
 }
 
@@ -382,25 +413,37 @@ e_modapi_init(E_Module *m)
    music_control_mod = m;
 
    ctxt->conf_edd = E_CONFIG_DD_NEW("music_control_config", Music_Control_Config);
-   #undef T
-   #undef D
-   #define T Music_Control_Config
-   #define D ctxt->conf_edd
+#undef T
+#undef D
+#define T Music_Control_Config
+#define D ctxt->conf_edd
    E_CONFIG_VAL(D, T, player_selected, INT);
    E_CONFIG_VAL(D, T, pause_on_desklock, INT);
    ctxt->config = e_config_domain_load(MUSIC_CONTROL_DOMAIN, ctxt->conf_edd);
    if (!ctxt->config)
-     ctxt->config = calloc(1, sizeof(Music_Control_Config));
+     {
+        ctxt->config = calloc(1, sizeof(Music_Control_Config));
+        ctxt->config->player_selected = -1;
+     }
 
-   if (!music_control_dbus_init(ctxt, music_player_players[ctxt->config->player_selected].dbus_name))
-     goto error_dbus_bus_get;
+   if (ctxt->config->player_selected < 0)
+     {
+     }
+   else
+     {
+        if (ctxt->config->player_selected >= PLAYER_COUNT)
+          ctxt->config->player_selected = PLAYER_COUNT - 1;
+        if (!music_control_dbus_init
+            (ctxt, music_player_players[ctxt->config->player_selected].dbus_name))
+          goto error_dbus_bus_get;
+     }
    music_control_mod = m;
 
    e_gadcon_provider_register(&_gc_class);
 
    if (ctxt->config->pause_on_desklock)
-     desklock_handler = ecore_event_handler_add(E_EVENT_DESKLOCK, _desklock_cb, ctxt);
-
+     desklock_handler = ecore_event_handler_add(E_EVENT_DESKLOCK,
+                                                _desklock_cb, ctxt);
    return ctxt;
 
 error_dbus_bus_get:
@@ -425,6 +468,9 @@ e_modapi_shutdown(E_Module *m EINA_UNUSED)
 
    E_FREE_FUNC(desklock_handler, ecore_event_handler_del);
 
+   eldbus_name_owner_changed_callback_del
+     (ctxt->conn, ctxt->dbus_name, cb_name_owner_changed, ctxt);
+   eina_stringshare_del(ctxt->dbus_name);
    media_player2_player_proxy_unref(ctxt->mpris2_player);
    mpris_media_player2_proxy_unref(ctxt->mrpis2);
    eldbus_connection_unref(ctxt->conn);
@@ -436,7 +482,6 @@ e_modapi_shutdown(E_Module *m EINA_UNUSED)
 
    free(ctxt);
    music_control_mod = NULL;
-
    return 1;
 }
 
