@@ -26,6 +26,7 @@ typedef struct _E_Music_Control_Module_Context
    Eldbus_Proxy *mpris2_player;
    E_Config_DD *conf_edd;
    Music_Control_Config *config;
+   const char *dbus_name;
    Eina_Bool actions_set E_BITFIELD;
 } E_Music_Control_Module_Context;
 
@@ -38,6 +39,7 @@ typedef struct _E_Music_Control_Instance
    Evas_Object *content_popup;
 } E_Music_Control_Instance;
 
+void music_control_launch(E_Music_Control_Instance *inst);
 void music_control_mouse_down_cb(void *data, Evas *evas, Evas_Object *obj, void *event);
 const char *music_control_edj_path_get(void);
 void music_control_popup_del(E_Music_Control_Instance *inst);
@@ -49,6 +51,7 @@ Eina_Bool _desklock_cb(void *data, int type, void *ev);
 typedef struct _Player {
    const char *name;
    const char *dbus_name;
+   const char *command;
 } Player;
 
 #endif
