@@ -712,7 +712,7 @@ _pager_desk_free(Pager_Desk *pd)
      evas_object_del(pd->drop_handler);
    pd->drop_handler = NULL;
    evas_object_del(pd->o_desk);
-   evas_object_del(pd->o_layout); 
+   evas_object_del(pd->o_layout);
    EINA_LIST_FREE(pd->wins, w)
        _pager_window_free(w);
    e_object_unref(E_OBJECT(pd->desk));
@@ -1757,41 +1757,17 @@ _pager_cb_event_client_property(void *data EINA_UNUSED, int type EINA_UNUSED, vo
 static Eina_Bool
 _pager_cb_event_zone_desk_count_set(void *data EINA_UNUSED, int type EINA_UNUSED, E_Event_Zone_Desk_Count_Set *ev)
 {
-   E_Desk *desk;
-   Eina_List *l, *ll;
+   Eina_List *l;
    Pager *p;
-   Pager_Desk *pd = NULL;
-   int x, y, xx, yy;
+   int xx, yy;
 
    xx = ev->zone->desk_x_count;
    yy = ev->zone->desk_y_count;
    EINA_LIST_FOREACH(pagers, l, p)
      {
-        if ((xx == p->xnum) && (yy == p->ynum))
-          continue;
-        for (x = 0; x < xx; x++)
-          {
-             for (y = 0; y < yy; y++)
-               {
-                  if ((x >= p->xnum) || (y >= p->ynum))
-                    {
-                       desk = e_desk_at_xy_get(p->zone, x, y);
-                       if (desk)
-                         pd = _pager_desk_new(p, desk, x, y, p->invert);
-                       if (pd)
-                         p->desks = eina_list_append(p->desks, pd);
-                    }
-               }
-          }
-        EINA_LIST_FOREACH(p->desks, ll, pd)
-          {
-             if (!e_desk_at_xy_get(p->zone, pd->xpos, pd->ypos))
-               {
-                  p->desks = eina_list_remove(p->desks, pd);
-                  _pager_desk_free(pd);
-               }
-          }
-        e_zone_desk_count_get(p->zone, &(p->xnum), &(p->ynum));
+        if ((xx == p->xnum) && (yy == p->ynum)) continue;
+        _pager_empty(p);
+        _pager_fill(p);
         if (p->inst) _pager_orient(p->inst, e_gadget_site_orient_get(e_gadget_site_get(p->inst->o_pager)));
      }
    return ECORE_CALLBACK_PASS_ON;
