@@ -98,7 +98,9 @@ _batman_popup_create(Instance *inst)
    elm_box_pack_end(box, label);
    evas_object_show(label);
 
-   if (inst->cfg->batman.have_power && (inst->cfg->batman.full < 99))
+   if (eina_list_count(batman_device_batteries) == 0)
+     snprintf(buf, sizeof(buf), _("No Battery Found"));
+   else if (inst->cfg->batman.have_power && (inst->cfg->batman.full < 99))
      snprintf(buf, sizeof(buf), _("Battery Charging"));
    else if (inst->cfg->batman.full >= 99)
      snprintf(buf, sizeof(buf), _("Battery Fully Charged"));
@@ -112,6 +114,16 @@ _batman_popup_create(Instance *inst)
         if (!eina_list_count(udis) || !eina_list_data_find(udis, bat->udi))
           {
              udis = eina_list_append(udis, bat->udi);
+             if (bat->vendor && bat->vendor[0] && bat->model && bat->model[0])
+               {
+                  label = elm_label_add(box);
+                  E_EXPAND(label); E_ALIGN(label, 0.5, 0.5);
+                  snprintf(buf, sizeof(buf), "%s (%s)", bat->vendor, bat->model);
+                  elm_object_text_set(label, buf);
+                  elm_box_pack_end(box, label);
+                  evas_object_show(label);
+               }
+
              pbar = elm_progressbar_add(box);
              E_EXPAND(pbar); E_FILL(pbar);
              elm_progressbar_span_size_set(pbar, 200 * e_scale);
@@ -347,7 +359,7 @@ _batman_device_update(Instance *inst)
 static Eina_Bool
 _screensaver_on(void *data)
 {
-#if defined(HAVE_EEZE)
+#if defined(HAVE_EEZE) || defined(__OpenBSD__) || defined(__DragonFly__) || defined(__FreeBSD__) || defined(__NetBSD__)
    Instance *inst = data;
 #else
    (void)data;
@@ -356,7 +368,7 @@ _screensaver_on(void *data)
 #if defined(HAVE_EEZE)
    _batman_udev_stop(inst);
 #elif defined(__OpenBSD__) || defined(__DragonFly__) || defined(__FreeBSD__) || defined(__NetBSD__)
-   _batman_sysctl_stop();
+   _batman_sysctl_stop(inst);
 #elif defined(upower)
    _batman_upower_stop();
 #else
@@ -571,7 +583,7 @@ _batman_removed_cb(void *data, Evas_Object *obj EINA_UNUSED, void *event_data)
 #if defined(HAVE_EEZE)
    _batman_udev_stop(inst);
 #elif defined(__OpenBSD__) || defined(__DragonFly__) || defined(__FreeBSD__) || defined(__NetBSD__)
-   _batman_sysctl_stop();
+   _batman_sysctl_stop(inst);
 #elif defined(upower)
    _batman_upower_stop();
 #else
@@ -604,8 +616,7 @@ sysinfo_batman_remove(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNU
 #if defined(HAVE_EEZE)
    _batman_udev_stop(inst);
 #elif defined(__OpenBSD__) || defined(__DragonFly__) || defined(__FreeBSD__) || defined(__NetBSD__)
-   (void)inst;
-   _batman_sysctl_stop();
+   _batman_sysctl_stop(inst);
 #elif defined(upower)
    (void)inst;
    _batman_upower_stop();
