@@ -58,13 +58,6 @@ struct _Battery
    Eina_Bool got_prop E_BITFIELD;
    Eldbus_Proxy *proxy;
    int * mib;
-#if defined(__FreeBSD__) || defined(__DragonFly__)
-   int * mib_state;
-   int * mib_units;
-   int * mib_time;
-   int batteries;
-   int time_min;
-#endif
 };
 
 struct _Ac_Adapter
@@ -106,12 +99,12 @@ EINTERN void _batman_udev_stop(Instance *inst);
 #elif !defined(__OpenBSD__) && !defined(__DragonFly__) && !defined(__FreeBSD__) && !defined(__NetBSD__)
 /* in batman_upower.c */
 EINTERN int _batman_upower_start(Instance *inst);
-EINTERNvoid _batman_upower_stop(void);
+EINTERN void _batman_upower_stop(void);
 /* end batman_upower.c */
 #else
 /* in batman_sysctl.c */
 EINTERN int _batman_sysctl_start(Instance *inst);
-EINTERN void _batman_sysctl_stop(void);
+EINTERN void _batman_sysctl_stop(Instance *inst);
 /* end batman_sysctl.c */
 #endif
 
