@@ -249,7 +249,7 @@ _device_type_cb(void *data, const Eldbus_Message *msg, Eldbus_Pending *pending)
         upower_proxy_ac = eldbus_proxy_get(obj, IFACE_PROPERTIES);
         _process_ac(ud->proxy, ud->inst);
      }
-   else if (type == 2) 
+   else if (type == 2)
      {
         obj = eldbus_object_get(conn, BUS, path);
         EINA_SAFETY_ON_FALSE_RETURN(obj);
@@ -350,7 +350,7 @@ _device_removed_cb(void *data, const Eldbus_Message *msg)
           }
      }
    exists = EINA_FALSE;
-   adapters = _batman_ac_adapter_get(path);
+   adapters = _batman_ac_adapter_find(path);
    if (eina_list_count(adapters))
      {
         EINA_LIST_FOREACH(adapters, l, ac)
