@@ -306,10 +306,14 @@ _tiling_window_tree_level_apply(Window_Tree *root, Evas_Coord x, Evas_Coord y,
         if (!e_object_is_del(E_OBJECT(root->client)))
           {
              if ((root->client->icccm.min_w > (w - padding)) ||
-                 (root->client->icccm.min_h > (h - padding)))
+                 (root->client->icccm.min_h > (h - padding))) {
                *floaters = eina_list_append(*floaters, root->client);
-             tiling_e_client_move_resize_extra(root->client, x, y,
-                                               w - padding, h - padding);
+             } else {
+               tiling_e_client_move_resize_extra(root->client, x, y,
+                                                 w - padding, h - padding);
+             }
+
+
           }
         return;
      }
