@@ -37,13 +37,13 @@ wizard_page_show(E_Wizard_Page *pg EINA_UNUSED)
    api->wizard_title_set(_("Adding missing App files"));
    api->wizard_button_next_enable_set(0);
    api->wizard_page_show(NULL);
-   
+
    snprintf(buf, sizeof(buf), "%s/extra_desktops", api->wizard_dir_get());
    extra_desks = ecore_file_ls(buf);
 
    /* advance in 1 sec */
    _next_timer = ecore_timer_loop_add(1.0, _next_page, NULL);
-   
+
    EINA_LIST_FREE(extra_desks, file)
      {
         snprintf(buf, sizeof(buf), "%s/extra_desktops/%s",
@@ -106,7 +106,7 @@ wizard_page_show(E_Wizard_Page *pg EINA_UNUSED)
      {
         if (_next_timer) ecore_timer_del(_next_timer);
         _next_timer = NULL;
-        return 0; /* we didnt copy anything so advance anyway */
+        return 0; /* we didn't copy anything so advance anyway */
      }
    return 1; /* 1 == show ui, and wait for user, 0 == just continue */
 }
